b=('jjael','jjaelg','jjaelm','jjaelb','jjaels','jjaelt','jjaelp','jjaelh','jjaem','jjaeb','jjaebs','jjaes','jjaess','jjaeng','jjaej','jjaech','jjaek','jjaet','jjaep','jjaeh','jjya','jjyag','jjyakk','jjyags','jjyan','jjyanj','jjyanh','jjyad','jjyal','jjyalg','jjyalm','jjyalb','jjyals','jjyalt','jjyalp','jjyalh','jjyam','jjyab','jjyabs','jjyas','jjyass','jjyang','jjyaj','jjyach','jjyak','jjyat','jjyap','jjyah','jjyae','jjyaeg','jjyaekk','jjyaegs','jjyaen','jjyaenj','jjyaenh','jjyaed','jjyael','jjyaelg','jjyaelm','jjyaelb','jjyaels','jjyaelt','jjyaelp','jjyaelh','jjyaem','jjyaeb','jjyaebs','jjyaes','jjyaess','jjyaeng','jjyaej','jjyaech','jjyaek','jjyaet','jjyaep','jjyaeh','jjeo','jjeog','jjeokk','jjeogs','jjeon','jjeonj','jjeonh','jjeod','jjeol','jjeolg','jjeolm','jjeolb','jjeols','jjeolt','jjeolp','jjeolh','jjeom','jjeob','jjeobs','jjeos','jjeoss','jjeong','jjeoj','jjeoch','jjeok','jjeot','jjeop','jjeoh','jje','jjeg','jjekk','jjegs','jjen','jjenj','jjenh','jjed','jjel','jjelg','jjelm','jjelb','jjels','jjelt','jjelp','jjelh','jjem','jjeb','jjebs','jjes','jjess','jjeng','jjej','jjech','jjek','jjet','jjep','jjeh','jjyeo','jjyeog','jjyeokk','jjyeogs','jjyeon','jjyeonj','jjyeonh','jjyeod','jjyeol','jjyeolg','jjyeolm','jjyeolb','jjyeols','jjyeolt','jjyeolp','jjyeolh','jjyeom','jjyeob','jjyeobs','jjyeos','jjyeoss','jjyeong','jjyeoj','jjyeoch','jjyeok','jjyeot','jjyeop','jjyeoh','jjye','jjyeg','jjyekk','jjyegs','jjyen','jjyenj','jjyenh','jjyed','jjyel','jjyelg','jjyelm','jjyelb','jjyels','jjyelt','jjyelp','jjyelh','jjyem','jjyeb','jjyebs','jjyes','jjyess','jjyeng','jjyej','jjyech','jjyek','jjyet','jjyep','jjyeh','jjo','jjog','jjokk','jjogs','jjon','jjonj','jjonh','jjod','jjol','jjolg','jjolm','jjolb','jjols','jjolt','jjolp','jjolh','jjom','jjob','jjobs','jjos','jjoss','jjong','jjoj','jjoch','jjok','jjot','jjop','jjoh','jjwa','jjwag','jjwakk','jjwags','jjwan','jjwanj','jjwanh','jjwad','jjwal','jjwalg','jjwalm','jjwalb','jjwals','jjwalt','jjwalp','jjwalh','jjwam','jjwab','jjwabs','jjwas','jjwass','jjwang','jjwaj','jjwach','jjwak','jjwat','jjwap','jjwah','jjwae','jjwaeg','jjwaekk','jjwaegs','jjwaen','jjwaenj','jjwaenh','jjwaed','jjwael','jjwaelg','jjwaelm','jjwaelb')


b=('Tong','Yu','Xiang','Nao','Shun','Fen','Pu','Ling','Ao','Huan','Yi','Huan','Meng','Ying','Lei','Yan','Bao','Die','Ling','Shi','Jiao','Lie','Jing','Ju','Ti','Pi','Gang','Xiao','Wai','Chuai','Di','Huan','Yao','Li','Mi','Hu','Sheng','Jia','Yin','Wei','','Piao','Lu','Ling','Yi','Cai','Shan','Hu','Shu','Tuo','Mo','Hua','Tie','Bing','Peng','Hun','Fu','Guo','Bu','Li','Chan','Pi','Cuo','Meng','Suo','Qiang','Zhi','Kuang','Bi','Ao','Meng','Xian','Ku','Tou','Tuan','Wei','Xian','Tan','Tuan','Lao','Chan','Ni','Ni','Li','Dong','Ju','Qian','Bo','Shai','Zha','Tao','Qian','Nong','Yi','Jing','Gan','Di','Jian','Mei','Da','Jian','Yu','Xie','Zai','Mang','Li','Gun','Xun','Ta','Zhe','Yang','Tuan','Shang','Xi','Qiao','Wei','Ying','Chua','Qu','Wa','Caau','Zhi','Ting','Gu','Shang','Ca','Fu','Tie','Ta','Ta','Zhuo','Han','Ping','He','Zhui','Zhou','Bo','Liu','Nu','Xi','Pao','Di','He','Ti','Wai','Ti','Qi','Ji','Chi','Ba','Jin','Ke','Li','Ju','Qu','La','Gu','Qia','Qi','Xian','Jian','Shi','Jian','Ai','Hua','Zha','Ze','Yao','Zhan','Ji','Cha','Yan','Jian','','Yan','Gwaai','Jiao','Tong','Nan','Yue','Ceoi','Chi','','','','','','','','','','','Qian','Kun','Zhun','Meng','Xu','Song','Shi','Bi','XiaoChu','Lu','Tai','Pi','TongRen','DaYou','Qian','Yu','Sui','Gu','Lin','Guan','ShiKe','Bi','Bo','Fu','WuWang','DaChu','Yi','DaGuo','Kan','Li','Xian','Heng','Dun','DaZhuang','Jin','MingYi','JiaRen','Kui','Jian','Xie','Sun','Yi','Guai','Gou','Cui','Sheng','Kun','Jing','Ge','Ding','Zhen','Gen','Jian','GuiMei','Feng','Lu','Xun','Dui','Huan','Jie','ZhongFu','XiaoGuo','JiJi','WeiJi')


b=('Dao','Diao','Dao','Ren','Ren','Chuang','Fen','Qie','Yi','Ji','Kan','Qian','Cun','Chu','Wen','Ji','Dan','Xing','Hua','Wan','Jue','Li','Yue','Lie','Liu','Ze','Gang','Chuang','Fu','Chu','Qu','Diao','Shan','Min','Ling','Zhong','Pan','Bie','Jie','Jie','Pao','Li','Shan','Bie','Chan','Jing','Gua','Geng','Dao','Chuang','Kui','Ku','Duo','Er','Zhi','Shua','Quan','Sha','Ci','Ke','Jie','Gui','Ci','Gui','Kai','Duo','Ji','Ti','Jing','Lou','Luo','Ze','Yuan','Cuo','Xue','Ke','La','Qian','Sha','Chuang','Gua','Jian','Cuo','Li','Ti','Fei','Pou','Chan','Qi','Chuang','Zi','Gang','Wan','Bo','Ji','Duo','Qing','Shan','Du','Jian','Ji','Bo','Yan','Ju','Huo','Sheng','Jian','Duo','Duan','Wu','Gua','Fu','Sheng','Jian','Ge','Da','Kai','Chuang','Chuan','Chan','Tuan','Lu','Li','Peng','Shan','Piao','Kou','Jiao','Gua','Qiao','Jue','Hua','Zha','Zhuo','Lian','Ju','Pi','Liu','Gui','Jiao','Gui','Jian','Jian','Tang','Huo','Ji','Jian','Yi','Jian','Zhi','Chan','Jian','Mo','Li','Zhu','Li','Ya','Quan','Ban','Gong','Jia','Wu','Mai','Lie','Jin','Keng','Xie','Zhi','Dong','Zhu','Nu','Jie','Qu','Shao','Yi','Zhu','Mo','Li','Jin','Lao','Lao','Juan','Kou','Yang','Wa','Xiao','Mou','Kuang','Jie','Lie','He','Shi','Ke','Jin','Gao','Bo','Min','Chi','Lang','Yong','Yong','Mian','Ke','Xun','Juan','Qing','Lu','Bu','Meng','Chi','Lei','Kai','Mian','Dong','Xu','Xu','Kan','Wu','Yi','Xun','Weng','Sheng','Lao','Mu','Lu','Piao','Shi','Ji','Qin','Jiang','Chao','Quan','Xiang','Yi','Jue','Fan','Juan','Tong','Ju','Dan','Xie','Mai','Xun','Xun','Lu','Li','Che','Rang','Quan','Bao','Shao','Yun','Jiu','Bao','Gou','Wu')


b=('Sha','Li','Han','Xian','Jing','Pai','Fei','Xiao','Bai','Qi','Ni','Biao','Yin','Lai','Lie','Jian','Qiang','Kun','Yan','Guo','Zong','Mi','Chang','Yi','Zhi','Zheng','Ya','Meng','Cai','Cu','She','Lie','Dian','Luo','Hu','Zong','Gui','Wei','Feng','Wo','Yuan','Xing','Zhu','Mao','Wei','Chuan','Xian','Tuan','Ya','Nao','Xie','Jia','Hou','Bian','You','You','Mei','Cha','Yao','Sun','Bo','Ming','Hua','Yuan','Sou','Ma','Yuan','Dai','Yu','Shi','Hao','Qiang','Yi','Zhen','Cang','Hao','Man','Jing','Jiang','Mo','Zhang','Chan','Ao','Ao','Hao','Cui','Ben','Jue','Bi','Bi','Huang','Pu','Lin','Xu','Tong','Yao','Liao','Shuo','Xiao','Shou','Dun','Jiao','Ge','Juan','Du','Hui','Kuai','Xian','Xie','Ta','Xian','Xun','Ning','Bian','Huo','Nou','Meng','Lie','Nao','Guang','Shou','Lu','Ta','Xian','Mi','Rang','Huan','Nao','Luo','Xian','Qi','Jue','Xuan','Miao','Zi','Lu','Lu','Yu','Su','Wang','Qiu','Ga','Ding','Le','Ba','Ji','Hong','Di','Chuan','Gan','Jiu','Yu','Qi','Yu','Chang','Ma','Hong','Wu','Fu','Wen','Jie','Ya','Bin','Bian','Bang','Yue','Jue','Men','Jue','Wan','Jian','Mei','Dan','Pin','Wei','Huan','Xian','Qiang','Ling','Dai','Yi','An','Ping','Dian','Fu','Xuan','Xi','Bo','Ci','Gou','Jia','Shao','Po','Ci','Ke','Ran','Sheng','Shen','Yi','Zu','Jia','Min','Shan','Liu','Bi','Zhen','Zhen','Jue','Fa','Long','Jin','Jiao','Jian','Li','Guang','Xian','Zhou','Gong','Yan','Xiu','Yang','Xu','Luo','Su','Zhu','Qin','Yin','Xun','Bao','Er','Xiang','Yao','Xia','Hang','Gui','Chong','Xu','Ban','Pei','Lao','Dang','Ying','Hui','Wen','E','Cheng','Di','Wu','Wu','Cheng','Jun','Mei','Bei','Ting','Xian','Chu')


b=('nyok','nyot','nyop','nyoh','nu','nug','nukk','nugs','nun','nunj','nunh','nud','nul','nulg','nulm','nulb','nuls','nult','nulp','nulh','num','nub','nubs','nus','nuss','nung','nuj','nuch','nuk','nut','nup','nuh','nwo','nwog','nwokk','nwogs','nwon','nwonj','nwonh','nwod','nwol','nwolg','nwolm','nwolb','nwols','nwolt','nwolp','nwolh','nwom','nwob','nwobs','nwos','nwoss','nwong','nwoj','nwoch','nwok','nwot','nwop','nwoh','nwe','nweg','nwekk','nwegs','nwen','nwenj','nwenh','nwed','nwel','nwelg','nwelm','nwelb','nwels','nwelt','nwelp','nwelh','nwem','nweb','nwebs','nwes','nwess','nweng','nwej','nwech','nwek','nwet','nwep','nweh','nwi','nwig','nwikk','nwigs','nwin','nwinj','nwinh','nwid','nwil','nwilg','nwilm','nwilb','nwils','nwilt','nwilp','nwilh','nwim','nwib','nwibs','nwis','nwiss','nwing','nwij','nwich','nwik','nwit','nwip','nwih','nyu','nyug','nyukk','nyugs','nyun','nyunj','nyunh','nyud','nyul','nyulg','nyulm','nyulb','nyuls','nyult','nyulp','nyulh','nyum','nyub','nyubs','nyus','nyuss','nyung','nyuj','nyuch','nyuk','nyut','nyup','nyuh','neu','neug','neukk','neugs','neun','neunj','neunh','neud','neul','neulg','neulm','neulb','neuls','neult','neulp','neulh','neum','neub','neubs','neus','neuss','neung','neuj','neuch','neuk','neut','neup','neuh','nui','nuig','nuikk','nuigs','nuin','nuinj','nuinh','nuid','nuil','nuilg','nuilm','nuilb','nuils','nuilt','nuilp','nuilh','nuim','nuib','nuibs','nuis','nuiss','nuing','nuij','nuich','nuik','nuit','nuip','nuih','ni','nig','nikk','nigs','nin','ninj','ninh','nid','nil','nilg','nilm','nilb','nils','nilt','nilp','nilh','nim','nib','nibs','nis','niss','ning','nij','nich','nik','nit','nip','nih','da','dag','dakk','dags','dan','danj','danh','dad','dal','dalg','dalm','dalb','dals','dalt','dalp','dalh','dam','dab','dabs','das','dass','dang','daj','dach','dak','dat','dap','dah')


b=('Fu','Zhuo','Mao','Fan','Jia','Mao','Mao','Ba','Ci','Mo','Zi','Zhi','Chi','Ji','Jing','Long','Cong','Niao','Yuan','Xue','Ying','Qiong','Ge','Ming','Li','Rong','Yin','Gen','Qian','Chai','Chen','Yu','Hao','Zi','Lie','Wu','Ji','Gui','Ci','Jian','Ci','Gou','Guang','Mang','Cha','Jiao','Jiao','Fu','Yu','Zhu','Zi','Jiang','Hui','Yin','Cha','Fa','Rong','Ru','Chong','Mang','Tong','Zhong','Qian','Zhu','Xun','Huan','Fu','Quan','Gai','Da','Jing','Xing','Chuan','Cao','Jing','Er','An','Qiao','Chi','Ren','Jian','Ti','Huang','Ping','Li','Jin','Lao','Shu','Zhuang','Da','Jia','Rao','Bi','Ce','Qiao','Hui','Ji','Dang','Zi','Rong','Hun','Xing','Luo','Ying','Xun','Jin','Sun','Yin','Mai','Hong','Zhou','Yao','Du','Wei','Li','Dou','Fu','Ren','Yin','He','Bi','Bu','Yun','Di','Tu','Sui','Sui','Cheng','Chen','Wu','Bie','Xi','Geng','Li','Pu','Zhu','Mo','Li','Zhuang','Zuo','Tuo','Qiu','Sha','Suo','Chen','Peng','Ju','Mei','Meng','Xing','Jing','Che','Shen','Jun','Yan','Ting','You','Cuo','Guan','Han','You','Cuo','Jia','Wang','Su','Niu','Shao','Xian','Lang','Fu','E','Mo','Wen','Jie','Nan','Mu','Kan','Lai','Lian','Shi','Wo','Tu','Xian','Huo','You','Ying','Ying','Gong','Chun','Mang','Mang','Ci','Wan','Jing','Di','Qu','Dong','Jian','Zou','Gu','La','Lu','Ju','Wei','Jun','Nie','Kun','He','Pu','Zai','Gao','Guo','Fu','Lun','Chang','Chou','Song','Chui','Zhan','Men','Cai','Ba','Li','Tu','Bo','Han','Bao','Qin','Juan','Xi','Qin','Di','Jie','Pu','Dang','Jin','Qiao','Tai','Geng','Hua','Gu','Ling','Fei','Qin','An','Wang','Beng','Zhou','Yan','Ju','Jian','Lin','Tan','Shu','Tian','Dao')


b=('Ruo','Bei','E','Shu','Juan','Yu','Yun','Hou','Kui','Xiang','Xiang','Sou','Tang','Ming','Xi','Ru','Chu','Zi','Zou','Ye','Wu','Xiang','Yun','Hao','Yong','Bi','Mao','Chao','Fu','Liao','Yin','Zhuan','Hu','Qiao','Yan','Zhang','Man','Qiao','Xu','Deng','Bi','Xun','Bi','Zeng','Wei','Zheng','Mao','Shan','Lin','Po','Dan','Meng','Ye','Cao','Kuai','Feng','Meng','Zou','Kuang','Lian','Zan','Chan','You','Ji','Yan','Chan','Cuo','Ling','Huan','Xi','Feng','Zan','Li','You','Ding','Qiu','Zhuo','Pei','Zhou','Yi','Gan','Yu','Jiu','Yan','Zui','Mao','Zhen','Xu','Dou','Zhen','Fen','Yuan','Fu','Yun','Tai','Tian','Qia','Tuo','Cu','Han','Gu','Su','Po','Chou','Zai','Ming','Lao','Chuo','Chou','You','Tong','Zhi','Xian','Jiang','Cheng','Yin','Tu','Jiao','Mei','Ku','Suan','Lei','Pu','Zui','Hai','Yan','Shai','Niang','Wei','Lu','Lan','Yan','Tao','Pei','Zhan','Chun','Tan','Zui','Zhui','Cu','Kun','Ti','Xian','Du','Hu','Xu','Xing','Tan','Qiu','Chun','Yun','Po','Ke','Sou','Mi','Quan','Chou','Cuo','Yun','Yong','Ang','Zha','Hai','Tang','Jiang','Piao','Chen','Yu','Li','Zao','Lao','Yi','Jiang','Bu','Jiao','Xi','Tan','Fa','Nong','Yi','Li','Ju','Yan','Yi','Niang','Ru','Xun','Chou','Yan','Ling','Mi','Mi','Niang','Xin','Jiao','Shai','Mi','Yan','Bian','Cai','Shi','You','Shi','Shi','Li','Zhong','Ye','Liang','Li','Jin','Jin','Qiu','Yi','Liao','Dao','Zhao','Ding','Po','Qiu','Ba','Fu','Zhen','Zhi','Ba','Luan','Fu','Nai','Diao','Shan','Qiao','Kou','Chuan','Zi','Fan','Hua','Hua','Han','Gang','Qi','Mang','Ri','Di','Si','Xi','Yi','Chai','Shi','Tu','Xi','Nu','Qian','Qiu','Jian','Pi','Ye','Jin')


b=('kkyeols','kkyeolt','kkyeolp','kkyeolh','kkyeom','kkyeob','kkyeobs','kkyeos','kkyeoss','kkyeong','kkyeoj','kkyeoch','kkyeok','kkyeot','kkyeop','kkyeoh','kkye','kkyeg','kkyekk','kkyegs','kkyen','kkyenj','kkyenh','kkyed','kkyel','kkyelg','kkyelm','kkyelb','kkyels','kkyelt','kkyelp','kkyelh','kkyem','kkyeb','kkyebs','kkyes','kkyess','kkyeng','kkyej','kkyech','kkyek','kkyet','kkyep','kkyeh','kko','kkog','kkokk','kkogs','kkon','kkonj','kkonh','kkod','kkol','kkolg','kkolm','kkolb','kkols','kkolt','kkolp','kkolh','kkom','kkob','kkobs','kkos','kkoss','kkong','kkoj','kkoch','kkok','kkot','kkop','kkoh','kkwa','kkwag','kkwakk','kkwags','kkwan','kkwanj','kkwanh','kkwad','kkwal','kkwalg','kkwalm','kkwalb','kkwals','kkwalt','kkwalp','kkwalh','kkwam','kkwab','kkwabs','kkwas','kkwass','kkwang','kkwaj','kkwach','kkwak','kkwat','kkwap','kkwah','kkwae','kkwaeg','kkwaekk','kkwaegs','kkwaen','kkwaenj','kkwaenh','kkwaed','kkwael','kkwaelg','kkwaelm','kkwaelb','kkwaels','kkwaelt','kkwaelp','kkwaelh','kkwaem','kkwaeb','kkwaebs','kkwaes','kkwaess','kkwaeng','kkwaej','kkwaech','kkwaek','kkwaet','kkwaep','kkwaeh','kkoe','kkoeg','kkoekk','kkoegs','kkoen','kkoenj','kkoenh','kkoed','kkoel','kkoelg','kkoelm','kkoelb','kkoels','kkoelt','kkoelp','kkoelh','kkoem','kkoeb','kkoebs','kkoes','kkoess','kkoeng','kkoej','kkoech','kkoek','kkoet','kkoep','kkoeh','kkyo','kkyog','kkyokk','kkyogs','kkyon','kkyonj','kkyonh','kkyod','kkyol','kkyolg','kkyolm','kkyolb','kkyols','kkyolt','kkyolp','kkyolh','kkyom','kkyob','kkyobs','kkyos','kkyoss','kkyong','kkyoj','kkyoch','kkyok','kkyot','kkyop','kkyoh','kku','kkug','kkukk','kkugs','kkun','kkunj','kkunh','kkud','kkul','kkulg','kkulm','kkulb','kkuls','kkult','kkulp','kkulh','kkum','kkub','kkubs','kkus','kkuss','kkung','kkuj','kkuch','kkuk','kkut','kkup','kkuh','kkwo','kkwog','kkwokk','kkwogs','kkwon','kkwonj','kkwonh','kkwod','kkwol','kkwolg','kkwolm','kkwolb','kkwols','kkwolt','kkwolp','kkwolh','kkwom','kkwob','kkwobs','kkwos','kkwoss','kkwong','kkwoj','kkwoch','kkwok','kkwot','kkwop','kkwoh','kkwe','kkweg','kkwekk','kkwegs','kkwen','kkwenj','kkwenh','kkwed','kkwel','kkwelg','kkwelm','kkwelb','kkwels','kkwelt','kkwelp','kkwelh')


b=('Guo','Yin','Hun','Pu','Yu','Han','Yuan','Lun','Quan','Yu','Qing','Guo','Chuan','Wei','Yuan','Quan','Ku','Pu','Yuan','Yuan','Ya','Tu','Tu','Tu','Tuan','Lue','Hui','Yi','Huan','Luan','Luan','Tu','Ya','Tu','Ting','Sheng','Pu','Lu','Kuai','Ya','Zai','Wei','Ge','Yu','Wu','Gui','Pi','Yi','De','Qian','Qian','Zhen','Zhuo','Dang','Qia','Xia','Shan','Kuang','Chang','Qi','Nie','Mo','Ji','Jia','Zhi','Zhi','Ban','Xun','Yi','Qin','Mei','Jun','Rong','Tun','Fang','Ben','Ben','Tan','Kan','Huai','Zuo','Keng','Bi','Jing','Di','Jing','Ji','Kuai','Di','Jing','Jian','Tan','Li','Ba','Wu','Fen','Zhui','Po','Ban','Tang','Kun','Qu','Tan','Zhi','Tuo','Gan','Ping','Dian','Gua','Ni','Tai','Pi','Jiong','Yang','Fo','Ao','Lu','Qiu','Mu','Ke','Gou','Xue','Ba','Chi','Che','Ling','Zhu','Fu','Hu','Zhi','Chui','La','Long','Long','Lu','Ao','Dai','Pao','Min','Xing','Dong','Ji','He','Lu','Ci','Chi','Lei','Gai','Yin','Hou','Dui','Zhao','Fu','Guang','Yao','Duo','Duo','Gui','Cha','Yang','Yin','Fa','Gou','Yuan','Die','Xie','Ken','Shang','Shou','E','Bing','Dian','Hong','Ya','Kua','Da','Ka','Dang','Kai','Hang','Nao','An','Xing','Xian','Yuan','Bang','Fu','Ba','Yi','Yin','Han','Xu','Chui','Qin','Geng','Ai','Beng','Fang','Que','Yong','Jun','Jia','Di','Mai','Lang','Juan','Cheng','Shan','Jin','Zhe','Lie','Lie','Bu','Cheng','Hua','Bu','Shi','Xun','Guo','Jiong','Ye','Nian','Di','Yu','Bu','Ya','Quan','Sui','Pi','Qing','Wan','Ju','Lun','Zheng','Kong','Chong','Dong','Dai','Tan','An','Cai','Chu','Beng','Kan','Zhi','Duo','Yi','Zhi','Yi','Pei','Ji','Zhun','Qi','Sao','Ju','Ni')


b=('syae','syaeg','syaekk','syaegs','syaen','syaenj','syaenh','syaed','syael','syaelg','syaelm','syaelb','syaels','syaelt','syaelp','syaelh','syaem','syaeb','syaebs','syaes','syaess','syaeng','syaej','syaech','syaek','syaet','syaep','syaeh','seo','seog','seokk','seogs','seon','seonj','seonh','seod','seol','seolg','seolm','seolb','seols','seolt','seolp','seolh','seom','seob','seobs','seos','seoss','seong','seoj','seoch','seok','seot','seop','seoh','se','seg','sekk','segs','sen','senj','senh','sed','sel','selg','selm','selb','sels','selt','selp','selh','sem','seb','sebs','ses','sess','seng','sej','sech','sek','set','sep','seh','syeo','syeog','syeokk','syeogs','syeon','syeonj','syeonh','syeod','syeol','syeolg','syeolm','syeolb','syeols','syeolt','syeolp','syeolh','syeom','syeob','syeobs','syeos','syeoss','syeong','syeoj','syeoch','syeok','syeot','syeop','syeoh','sye','syeg','syekk','syegs','syen','syenj','syenh','syed','syel','syelg','syelm','syelb','syels','syelt','syelp','syelh','syem','syeb','syebs','syes','syess','syeng','syej','syech','syek','syet','syep','syeh','so','sog','sokk','sogs','son','sonj','sonh','sod','sol','solg','solm','solb','sols','solt','solp','solh','som','sob','sobs','sos','soss','song','soj','soch','sok','sot','sop','soh','swa','swag','swakk','swags','swan','swanj','swanh','swad','swal','swalg','swalm','swalb','swals','swalt','swalp','swalh','swam','swab','swabs','swas','swass','swang','swaj','swach','swak','swat','swap','swah','swae','swaeg','swaekk','swaegs','swaen','swaenj','swaenh','swaed','swael','swaelg','swaelm','swaelb','swaels','swaelt','swaelp','swaelh','swaem','swaeb','swaebs','swaes','swaess','swaeng','swaej','swaech','swaek','swaet','swaep','swaeh','soe','soeg','soekk','soegs','soen','soenj','soenh','soed','soel','soelg','soelm','soelb','soels','soelt','soelp','soelh','soem','soeb','soebs','soes','soess','soeng','soej','soech','soek','soet','soep','soeh','syo','syog','syokk','syogs')


b=('Huan','Quan','Zei','Wei','Wei','Yu','Chun','Rou','Die','Huang','Lian','Yan','Qiu','Qiu','Jian','Bi','E','Yang','Fu','Sai','Gan','Xia','Tuo','Hu','Shi','Ruo','Xuan','Wen','Qian','Hao','Wu','Fang','Sao','Liu','Ma','Shi','Shi','Guan','Zi','Teng','Ta','Yao','E','Yong','Qian','Qi','Wen','Ruo','Shen','Lian','Ao','Le','Hui','Min','Ji','Tiao','Qu','Jian','Shen','Man','Xi','Qiu','Biao','Ji','Ji','Zhu','Jiang','Xiu','Zhuan','Yong','Zhang','Kang','Xue','Bie','Yu','Qu','Xiang','Bo','Jiao','Xun','Su','Huang','Zun','Shan','Shan','Fan','Gui','Lin','Xun','Miao','Xi','Zeng','Xiang','Fen','Guan','Hou','Kuai','Zei','Sao','Zhan','Gan','Gui','Ying','Li','Chang','Lei','Shu','Ai','Ru','Ji','Xu','Hu','Shu','Li','Lie','Li','Mie','Zhen','Xiang','E','Lu','Guan','Li','Xian','Yu','Dao','Ji','You','Tun','Lu','Fang','Ba','He','Ba','Ping','Nian','Lu','You','Zha','Fu','Ba','Bao','Hou','Pi','Tai','Gui','Jie','Kao','Wei','Er','Tong','Zei','Hou','Kuai','Ji','Jiao','Xian','Zha','Xiang','Xun','Geng','Li','Lian','Jian','Li','Shi','Tiao','Gun','Sha','Huan','Jun','Ji','Yong','Qing','Ling','Qi','Zou','Fei','Kun','Chang','Gu','Ni','Nian','Diao','Jing','Shen','Shi','Zi','Fen','Die','Bi','Chang','Ti','Wen','Wei','Sai','E','Qiu','Fu','Huang','Quan','Jiang','Bian','Sao','Ao','Qi','Ta','Guan','Yao','Pang','Jian','Le','Biao','Xue','Bie','Man','Min','Yong','Wei','Xi','Gui','Shan','Lin','Zun','Hu','Gan','Li','Zhan','Guan','Niao','Yi','Fu','Li','Jiu','Bu','Yan','Fu','Diao','Ji','Feng','Ru','Gan','Shi','Feng','Ming','Bao','Yuan','Zhi','Hu','Qin','Fu','Ban','Wen','Jian','Shi','Yu')


b=('Shu','Xuan','Feng','Shen','Shen','Fu','Xian','Zhe','Wu','Fu','Li','Lang','Bi','Chu','Yuan','You','Jie','Dan','Yan','Ting','Dian','Tui','Hui','Wo','Zhi','Song','Fei','Ju','Mi','Qi','Qi','Yu','Jun','La','Meng','Qiang','Si','Xi','Lun','Li','Die','Tiao','Tao','Kun','Han','Han','Yu','Bang','Fei','Pi','Wei','Dun','Yi','Yuan','Suo','Quan','Qian','Rui','Ni','Qing','Wei','Liang','Guo','Wan','Dong','E','Ban','Di','Wang','Can','Yang','Ying','Guo','Chan','Ding','La','Ke','Jie','Xie','Ting','Mao','Xu','Mian','Yu','Jie','Shi','Xuan','Huang','Yan','Bian','Rou','Wei','Fu','Yuan','Mei','Wei','Fu','Ru','Xie','You','Qiu','Mao','Xia','Ying','Shi','Chong','Tang','Zhu','Zong','Ti','Fu','Yuan','Kui','Meng','La','Du','Hu','Qiu','Die','Li','Wo','Yun','Qu','Nan','Lou','Chun','Rong','Ying','Jiang','Ban','Lang','Pang','Si','Xi','Ci','Xi','Yuan','Weng','Lian','Sou','Ban','Rong','Rong','Ji','Wu','Xiu','Han','Qin','Yi','Bi','Hua','Tang','Yi','Du','Nai','He','Hu','Gui','Ma','Ming','Yi','Wen','Ying','Te','Zhong','Cang','Sao','Qi','Man','Tiao','Shang','Shi','Cao','Chi','Di','Ao','Lu','Wei','Zhi','Tang','Chen','Piao','Qu','Pi','Yu','Jian','Luo','Lou','Qin','Zhong','Yin','Jiang','Shuai','Wen','Xiao','Wan','Zhe','Zhe','Ma','Ma','Guo','Liu','Mao','Xi','Cong','Li','Man','Xiao','Chang','Zhang','Mang','Xiang','Mo','Zui','Si','Qiu','Te','Zhi','Peng','Peng','Jiao','Qu','Bie','Liao','Pan','Gui','Xi','Ji','Zhuan','Huang','Fei','Lao','Jue','Jue','Hui','Yin','Chan','Jiao','Shan','Nao','Xiao','Wu','Chong','Xun','Si','Chu','Cheng','Dang','Li','Xie','Shan','Yi','Jing','Da','Chan','Qi')


b=('Lun','Guo','Ling','Pi','Lu','Li','Qiang','Pou','Juan','Min','Zui','Peng','An','Pi','Xian','Ya','Zhui','Lei','Ke','Kong','Ta','Kun','Du','Nei','Chui','Zi','Zheng','Ben','Nie','Zong','Chun','Tan','Ding','Qi','Qian','Zhui','Ji','Yu','Jin','Guan','Mao','Chang','Tian','Xi','Lian','Tao','Gu','Cuo','Shu','Zhen','Lu','Meng','Lu','Hua','Biao','Ga','Lai','Ken','Fang','Wu','Nai','Wan','Zan','Hu','De','Xian','Pian','Huo','Liang','Fa','Men','Kai','Ying','Di','Lian','Guo','Xian','Du','Tu','Wei','Zong','Fu','Rou','Ji','E','Jun','Chen','Ti','Zha','Hu','Yang','Duan','Xia','Yu','Keng','Sheng','Huang','Wei','Fu','Zhao','Cha','Qie','Shi','Hong','Kui','Tian','Mou','Qiao','Qiao','Hou','Tou','Cong','Huan','Ye','Min','Jian','Duan','Jian','Song','Kui','Hu','Xuan','Duo','Jie','Zhen','Bian','Zhong','Zi','Xiu','Ye','Mei','Pai','Ai','Jie','Qian','Mei','Suo','Da','Bang','Xia','Lian','Suo','Kai','Liu','Yao','Ye','Nou','Weng','Rong','Tang','Suo','Qiang','Li','Shuo','Chui','Bo','Pan','Da','Bi','Sang','Gang','Zi','Wu','Ying','Huang','Tiao','Liu','Kai','Sun','Sha','Sou','Wan','Hao','Zhen','Zhen','Lang','Yi','Yuan','Tang','Nie','Xi','Jia','Ge','Ma','Juan','Song','Zu','Suo','Xia','Feng','Wen','Na','Lu','Suo','Ou','Zu','Tuan','Xiu','Guan','Xuan','Lian','Shou','Ao','Man','Mo','Luo','Bi','Wei','Liu','Di','San','Zong','Yi','Lu','Ao','Keng','Qiang','Cui','Qi','Chang','Tang','Man','Yong','Chan','Feng','Jing','Biao','Shu','Lou','Xiu','Cong','Long','Zan','Jian','Cao','Li','Xia','Xi','Kang','Shuang','Beng','Zhang','Qian','Cheng','Lu','Hua','Ji','Pu','Hui','Qiang','Po','Lin','Se','Xiu','San','Cheng')


b=('Chu','Jing','Nie','Xiao','Bu','Xue','Cun','Mu','Shu','Liang','Yong','Jiao','Chou','Qiao','Mou','Ta','Jian','Qi','Wo','Wei','Chuo','Jie','Ji','Nie','Ju','Nie','Lun','Lu','Leng','Huai','Ju','Chi','Wan','Quan','Ti','Bo','Zu','Qie','Yi','Cu','Zong','Cai','Zong','Peng','Zhi','Zheng','Dian','Zhi','Yu','Duo','Dun','Chuan','Yong','Zhong','Di','Zha','Chen','Chuai','Jian','Gua','Tang','Ju','Fu','Zu','Die','Pian','Rou','Nuo','Ti','Cha','Tui','Jian','Dao','Cuo','Qi','Ta','Qiang','Nian','Dian','Ti','Ji','Nie','Man','Liu','Zan','Bi','Chong','Lu','Liao','Cu','Tang','Dai','Su','Xi','Kui','Ji','Zhi','Qiang','Di','Pan','Zong','Lian','Beng','Zao','Nian','Bie','Tui','Ju','Deng','Ceng','Xian','Fan','Chu','Zhong','Dun','Bo','Cu','Cu','Jue','Jue','Lin','Ta','Qiao','Jue','Pu','Liao','Dun','Cuan','Guan','Zao','Da','Bi','Bi','Zhu','Ju','Chu','Qiao','Dun','Chou','Ji','Wu','Yue','Nian','Lin','Lie','Zhi','Li','Zhi','Chan','Chu','Duan','Wei','Long','Lin','Xian','Wei','Zuan','Lan','Xie','Rang','Sa','Nie','Ta','Qu','Ji','Cuan','Cuo','Xi','Kui','Jue','Lin','Shen','Gong','Dan','Fen','Qu','Ti','Duo','Duo','Gong','Lang','Ren','Luo','Ai','Ji','Ju','Tang','Kong','Lao','Yan','Mei','Kang','Qu','Lou','Lao','Duo','Zhi','Yan','Ti','Dao','Ying','Yu','Che','Ya','Gui','Jun','Wei','Yue','Xin','Dai','Xuan','Fan','Ren','Shan','Kuang','Shu','Tun','Chen','Dai','E','Na','Qi','Mao','Ruan','Kuang','Qian','Zhuan','Hong','Hu','Qu','Kuang','Di','Ling','Dai','Ao','Zhen','Fan','Kuang','Yang','Peng','Bei','Gu','Gu','Pao','Zhu','Rong','E','Ba','Zhou','Zhi','Yao','Ke','Yi','Zhi','Shi','Ping')


b=('Ji','Cha','Zhou','Xun','Yue','Hong','Yu','He','Wan','Ren','Wen','Wen','Qiu','Na','Zi','Tou','Niu','Fou','Ji','Shu','Chun','Pi','Zhen','Sha','Hong','Zhi','Ji','Fen','Yun','Ren','Dan','Jin','Su','Fang','Suo','Cui','Jiu','Za','Ba','Jin','Fu','Zhi','Qi','Zi','Chou','Hong','Za','Lei','Xi','Fu','Xie','Shen','Bo','Zhu','Qu','Ling','Zhu','Shao','Gan','Yang','Fu','Tuo','Zhen','Dai','Chu','Shi','Zhong','Xian','Zu','Jiong','Ban','Qu','Mo','Shu','Zui','Kuang','Jing','Ren','Hang','Xie','Jie','Zhu','Chou','Gua','Bai','Jue','Kuang','Hu','Ci','Huan','Geng','Tao','Jie','Ku','Jiao','Quan','Gai','Luo','Xuan','Beng','Xian','Fu','Gei','Dong','Rong','Tiao','Yin','Lei','Xie','Juan','Xu','Gai','Die','Tong','Si','Jiang','Xiang','Hui','Jue','Zhi','Jian','Juan','Chi','Mian','Zhen','Lu','Cheng','Qiu','Shu','Bang','Tong','Xiao','Huan','Qin','Geng','Xiu','Ti','Tou','Xie','Hong','Xi','Fu','Ting','Sui','Dui','Kun','Fu','Jing','Hu','Zhi','Yan','Jiong','Feng','Ji','Xu','Ren','Zong','Chen','Duo','Li','Lu','Liang','Chou','Quan','Shao','Qi','Qi','Zhun','Qi','Wan','Qian','Xian','Shou','Wei','Qi','Tao','Wan','Gang','Wang','Beng','Zhui','Cai','Guo','Cui','Lun','Liu','Qi','Zhan','Bi','Chuo','Ling','Mian','Qi','Qie','Tian','Zong','Gun','Zou','Xi','Zi','Xing','Liang','Jin','Fei','Rui','Min','Yu','Zong','Fan','Lu','Xu','Ying','Shang','Qi','Xu','Xiang','Jian','Ke','Xian','Ruan','Mian','Ji','Duan','Chong','Di','Min','Miao','Yuan','Xie','Bao','Si','Qiu','Bian','Huan','Geng','Cong','Mian','Wei','Fu','Wei','Tou','Gou','Miao','Xie','Lian','Zong','Bian','Yun','Yin','Ti','Gua','Zhi','Yun','Cheng','Chan','Dai')


b=('Yi','Ding','Kao','Qi','Shang','Xia','Han','Wan','Zhang','San','Shang','Xia','Ji','Bu','Yu','Mian','Gai','Chou','Chou','Zhuan','Qie','Pi','Shi','Shi','Qiu','Bing','Ye','Cong','Dong','Si','Cheng','Diu','Qiu','Liang','Diu','You','Liang','Yan','Bing','Sang','Gun','Jiu','Ge','Ya','Qiang','Zhong','Ji','Jie','Feng','Guan','Chuan','Chan','Lin','Zhuo','Zhu','Ba','Wan','Dan','Wei','Zhu','Jing','Li','Ju','Pie','Fu','Yi','Yi','Nai','Wu','Jiu','Jiu','Tuo','Me','Yi','Yi','Zhi','Wu','Zha','Hu','Fa','Le','Yin','Ping','Pang','Qiao','Hu','Guai','Cheng','Cheng','Yi','Yin','Ya','Mie','Jiu','Qi','Ye','Xi','Xiang','Gai','Jiu','Xia','Hu','Shu','Dou','Shi','Ji','Nang','Jia','Ju','Shi','Mao','Hu','Mai','Luan','Zi','Ru','Xue','Yan','Fu','Sha','Na','Gan','Suo','Yu','Cui','Zhe','Gan','Zhi','Gui','Gan','Luan','Lin','Yi','Jue','Le','Ma','Yu','Zheng','Shi','Shi','Er','Chu','Yu','Kui','Yu','Yun','Hu','Qi','Wu','Jing','Si','Sui','Gen','Gen','Ya','Xie','Ya','Qi','Ya','Ji','Tou','Wang','Kang','Da','Jiao','Hai','Yi','Chan','Heng','Mu','Ye','Xiang','Jing','Ting','Liang','Xiang','Jing','Ye','Qin','Bo','You','Xie','Dan','Lian','Duo','Men','Ren','Ren','Ji','Ji','Wang','Yi','Shen','Ren','Le','Ding','Ze','Jin','Pu','Chou','Ba','Zhang','Jin','Jie','Bing','Reng','Cong','Fo','San','Lun','Bing','Cang','Zi','Shi','Ta','Zhang','Fu','Xian','Xian','Tuo','Hong','Tong','Ren','Qian','Gan','Ge','Bo','Dai','Ling','Yi','Chao','Chang','Sa','Chang','Yi','Mu','Men','Ren','Fan','Chao','Yang','Qian','Zhong','Pi','Wo','Wu','Jian','Jia','Yao','Feng','Cang','Ren','Wang','Fen','Di','Fang')


b=('hyeo','hyeog','hyeokk','hyeogs','hyeon','hyeonj','hyeonh','hyeod','hyeol','hyeolg','hyeolm','hyeolb','hyeols','hyeolt','hyeolp','hyeolh','hyeom','hyeob','hyeobs','hyeos','hyeoss','hyeong','hyeoj','hyeoch','hyeok','hyeot','hyeop','hyeoh','hye','hyeg','hyekk','hyegs','hyen','hyenj','hyenh','hyed','hyel','hyelg','hyelm','hyelb','hyels','hyelt','hyelp','hyelh','hyem','hyeb','hyebs','hyes','hyess','hyeng','hyej','hyech','hyek','hyet','hyep','hyeh','ho','hog','hokk','hogs','hon','honj','honh','hod','hol','holg','holm','holb','hols','holt','holp','holh','hom','hob','hobs','hos','hoss','hong','hoj','hoch','hok','hot','hop','hoh','hwa','hwag','hwakk','hwags','hwan','hwanj','hwanh','hwad','hwal','hwalg','hwalm','hwalb','hwals','hwalt','hwalp','hwalh','hwam','hwab','hwabs','hwas','hwass','hwang','hwaj','hwach','hwak','hwat','hwap','hwah','hwae','hwaeg','hwaekk','hwaegs','hwaen','hwaenj','hwaenh','hwaed','hwael','hwaelg','hwaelm','hwaelb','hwaels','hwaelt','hwaelp','hwaelh','hwaem','hwaeb','hwaebs','hwaes','hwaess','hwaeng','hwaej','hwaech','hwaek','hwaet','hwaep','hwaeh','hoe','hoeg','hoekk','hoegs','hoen','hoenj','hoenh','hoed','hoel','hoelg','hoelm','hoelb','hoels','hoelt','hoelp','hoelh','hoem','hoeb','hoebs','hoes','hoess','hoeng','hoej','hoech','hoek','hoet','hoep','hoeh','hyo','hyog','hyokk','hyogs','hyon','hyonj','hyonh','hyod','hyol','hyolg','hyolm','hyolb','hyols','hyolt','hyolp','hyolh','hyom','hyob','hyobs','hyos','hyoss','hyong','hyoj','hyoch','hyok','hyot','hyop','hyoh','hu','hug','hukk','hugs','hun','hunj','hunh','hud','hul','hulg','hulm','hulb','huls','hult','hulp','hulh','hum','hub','hubs','hus','huss','hung','huj','huch','huk','hut','hup','huh','hwo','hwog','hwokk','hwogs','hwon','hwonj','hwonh','hwod','hwol','hwolg','hwolm','hwolb','hwols','hwolt','hwolp','hwolh','hwom','hwob','hwobs','hwos','hwoss','hwong','hwoj','hwoch','hwok','hwot','hwop','hwoh','hwe','hweg','hwekk','hwegs')


b=('Ku','Ke','Tang','Kun','Ni','Jian','Dui','Jin','Gang','Yu','E','Peng','Gu','Tu','Leng','Fang','Ya','Qian','Kun','An','Shen','Duo','Nao','Tu','Cheng','Yin','Hun','Bi','Lian','Guo','Die','Zhuan','Hou','Bao','Bao','Yu','Di','Mao','Jie','Ruan','Ye','Geng','Kan','Zong','Yu','Huang','E','Yao','Yan','Bao','Ci','Mei','Chang','Du','Tuo','Yin','Feng','Zhong','Jie','Jin','Heng','Gang','Chun','Jian','Ping','Lei','Xiang','Huang','Leng','Duan','Wan','Xuan','Ji','Ji','Kuai','Ying','Ta','Cheng','Yong','Kai','Su','Su','Shi','Mi','Ta','Weng','Cheng','Tu','Tang','Que','Zhong','Li','Zhong','Bang','Sai','Zang','Dui','Tian','Wu','Zheng','Xun','Ge','Zhen','Ai','Gong','Yan','Kan','Tian','Yuan','Wen','Xie','Liu','Hai','Lang','Chang','Peng','Beng','Chen','Lu','Lu','Ou','Qian','Mei','Mo','Zhuan','Shuang','Shu','Lou','Chi','Man','Biao','Jing','Ce','Shu','Zhi','Zhang','Kan','Yong','Dian','Chen','Zhi','Xi','Guo','Qiang','Jin','Di','Shang','Mu','Cui','Yan','Ta','Zeng','Qian','Qiang','Liang','Wei','Zhui','Qiao','Zeng','Xu','Shan','Shan','Ba','Pu','Kuai','Dong','Fan','Que','Mo','Dun','Dun','Zun','Di','Sheng','Duo','Duo','Tan','Deng','Mu','Fen','Huang','Tan','Da','Ye','Zhu','Jian','Ao','Qiang','Ji','Qiao','Ken','Yi','Pi','Bi','Dian','Jiang','Ye','Yong','Xue','Tan','Lan','Ju','Huai','Dang','Rang','Qian','Xun','Xian','Xi','He','Ai','Ya','Dao','Hao','Ruan','Jin','Lei','Kuang','Lu','Yan','Tan','Wei','Huai','Long','Long','Rui','Li','Lin','Rang','Chan','Xun','Yan','Lei','Ba','Wan','Shi','Ren','San','Zhuang','Zhuang','Sheng','Yi','Mai','Ke','Zhu','Zhuang','Hu','Hu','Kun','Yi','Hu','Xu','Kun','Shou','Mang','Zun')


b=('Fan','You','An','Tui','Meng','She','Jin','Gu','Ji','Qiao','Jiao','Yan','Xi','Kan','Mian','Xuan','Shan','Wo','Qian','Huan','Ren','Zhen','Tian','Jue','Xie','Qi','Ang','Mei','Gu','Bei','Tao','Fan','Ju','Chan','Shun','Bi','Mao','Shuo','Gu','Hong','Hua','Luo','Hang','Jia','Quan','Gai','Huang','Bu','Gu','Feng','Mu','Ai','Ying','Shun','Liang','Jie','Chi','Jie','Chou','Ping','Chen','Yan','Du','Di','','Liang','Xian','Biao','Xing','Meng','Ye','Mi','Qi','Qi','Wo','Xie','Yu','Qia','Cheng','Yao','Ying','Yang','Ji','Zong','Xuan','Min','Lou','Kai','Yao','Yan','Sun','Gui','Huang','Ying','Sheng','Cha','Lian','','Xuan','Chuan','Che','Ni','Qu','Miao','Huo','Yu','Zhan','Hu','Ceng','Biao','Qian','Xi','Jiang','Kou','Mai','Mang','Zhan','Bian','Ji','Jue','Nang','Bi','Shi','Shuo','Mo','Lie','Mie','Mo','Xi','Chan','Qu','Jiao','Huo','Xian','Xu','Niu','Tong','Hou','Yu','','Chong','Bo','Zuan','Diao','Zhuo','Ji','Qia','Kwai','Xing','Hui','Shi','Ku','Caam','Dui','Yao','Yu','Bang','Jie','Zhe','Jia','Shi','Di','Dong','Ci','Fu','Min','Zhen','Zhen','Cik','Yan','Qiao','Hang','Gong','Qiao','Lue','Guai','La','Rui','Fa','Cuo','Yan','Gong','Jie','Guai','Guo','Suo','Wo','Zheng','Nie','Diao','Lai','Ta','Cui','Ya','Gun','','','Di','','Mian','Jie','Min','Ju','Yu','Zhen','Zhao','Zha','Xing','','Ban','He','Gou','Hong','Lao','Wu','Bo','Keng','Lu','Cu','Lian','Yi','Qiao','Shu','Saan','Xuan','Jin','Qin','Hui','Su','Chuang','Dun','Long','','Nao','Tan','Dan','Wei','Gan','Da','Li','Ca','Xian','Pan','La','Zhu','Niao','Huai','Ying','Xian','Lan','Mo','Ba','','Gui','Bi','Fu')


b=('Dang','Ma','Sha','Dan','Jue','Li','Fu','Min','E','Huo','Kang','Zhi','Qi','Kan','Jie','Bin','E','Ya','Pi','Zhe','Yan','Sui','Zhuan','Che','Dun','Wa','Yan','Jin','Feng','Fa','Mo','Zha','Ju','Yu','Ke','Tuo','Tuo','Di','Zhai','Zhen','E','Fu','Mu','Zhu','La','Bian','Nu','Ping','Peng','Ling','Pao','Le','Po','Bo','Po','Shen','Za','Ai','Li','Long','Tong','Yong','Li','Kuang','Chu','Keng','Quan','Zhu','Kuang','Gui','E','Nao','Qia','Lu','Wei','Ai','Ge','Xian','Xing','Yan','Dong','Peng','Xi','Lao','Hong','Shuo','Xia','Qiao','Qing','Wei','Qiao','Yi','Keng','Xiao','Que','Chan','Lang','Hong','Yu','Xiao','Xia','Mang','Luo','Yong','Che','Che','Wo','Liu','Ying','Mang','Que','Yan','Sha','Kun','Yu','Chi','Hua','Lu','Chen','Jian','Nue','Song','Zhuo','Keng','Peng','Yan','Zhui','Kong','Cheng','Qi','Zong','Qing','Lin','Jun','Bo','Ding','Min','Diao','Jian','He','Lu','Ai','Sui','Que','Leng','Bei','Yin','Dui','Wu','Qi','Lun','Wan','Dian','Nao','Bei','Qi','Chen','Ruan','Yan','Die','Ding','Du','Tuo','Jie','Ying','Bian','Ke','Bi','Wei','Shuo','Zhen','Duan','Xia','Dang','Ti','Nao','Peng','Jian','Di','Tan','Cha','Tian','Qi','Dun','Feng','Xuan','Que','Que','Ma','Gong','Nian','Su','E','Ci','Liu','Si','Tang','Bang','Hua','Pi','Wei','Sang','Lei','Cuo','Tian','Xia','Xi','Lian','Pan','Wei','Yun','Dui','Zhe','Ke','La','Zhuan','Yao','Gun','Zhuan','Chan','Qi','Ao','Peng','Liu','Lu','Kan','Chuang','Chen','Yin','Lei','Biao','Qi','Mo','Qi','Cui','Zong','Qing','Chuo','Lun','Ji','Shan','Lao','Qu','Zeng','Deng','Jian','Xi','Lin','Ding','Tan','Huang','Pan','Za','Qiao','Di','Li')


b=('qiet','qiex','qie','qiep','quot','quox','quo','quop','qot','qox','qo','qop','qut','qux','qu','qup','qurx','qur','qyt','qyx','qy','qyp','qyrx','qyr','jjit','jjix','jji','jjip','jjiet','jjiex','jjie','jjiep','jjuox','jjuo','jjuop','jjot','jjox','jjo','jjop','jjut','jjux','jju','jjup','jjurx','jjur','jjyt','jjyx','jjy','jjyp','njit','njix','nji','njip','njiet','njiex','njie','njiep','njuox','njuo','njot','njox','njo','njop','njux','nju','njup','njurx','njur','njyt','njyx','njy','njyp','njyrx','njyr','nyit','nyix','nyi','nyip','nyiet','nyiex','nyie','nyiep','nyuox','nyuo','nyuop','nyot','nyox','nyo','nyop','nyut','nyux','nyu','nyup','xit','xix','xi','xip','xiet','xiex','xie','xiep','xuox','xuo','xot','xox','xo','xop','xyt','xyx','xy','xyp','xyrx','xyr','yit','yix','yi','yip','yiet','yiex','yie','yiep','yuot','yuox','yuo','yuop','yot','yox','yo','yop','yut','yux','yu','yup','yurx','yur','yyt','yyx','yy','yyp','yyrx','yyr','','','','QOT','LI','KIT','NYIP','CYP','SSI','GGOP','GEP','MI','HXIT','LYR','BBUT','MOP','YO','PUT','HXUO','TAT','GA','ZUP','CYT','DDUR','BUR','GGUO','NYOP','TU','OP','JJUT','ZOT','PYT','HMO','YIT','VUR','SHY','VEP','ZA','JO','NZUP','JJY','GOT','JJIE','WO','DU','SHUR','LIE','CY','CUOP','CIP','HXOP','SHAT','ZUR','SHOP','CHE','ZZIET','NBIE','KE')


b=('Bai','Chi','Gua','Zhi','Kuo','Duo','Duo','Zhi','Qie','An','Nong','Zhen','Ge','Jiao','Kua','Dong','Na','Tiao','Lie','Zha','Lu','Die','Wa','Jue','Lie','Ju','Zhi','Luan','Ya','Wo','Ta','Xie','Nao','Dang','Jiao','Zheng','Ji','Hui','Xian','Yu','Ai','Tuo','Nuo','Cuo','Bo','Geng','Ti','Zhen','Cheng','Sa','Sa','Keng','Mei','Nong','Ju','Peng','Jian','Yi','Ting','Shan','Rua','Wan','Xie','Cha','Feng','Jiao','Wu','Jun','Jiu','Tong','Kun','Huo','Tu','Zhuo','Pou','Lu','Ba','Han','Shao','Nie','Juan','Ze','Shu','Ye','Jue','Bu','Wan','Bu','Zun','Ye','Zhai','Lu','Sou','Tuo','Lao','Sun','Bang','Jian','Huan','Dao','Wei','Wan','Qin','Peng','She','Lie','Min','Men','Fu','Bai','Ju','Dao','Wo','Ai','Juan','Yue','Zong','Chen','Chui','Jie','Tu','Ben','Na','Nian','Ruo','Zuo','Wo','Qi','Xian','Cheng','Dian','Sao','Lun','Qing','Gang','Duo','Shou','Diao','Pou','Di','Zhang','Hun','Ji','Tao','Qia','Qi','Pai','Shu','Qian','Ling','Ye','Ya','Jue','Zheng','Liang','Gua','Yi','Huo','Shan','Zheng','Lue','Cai','Tan','Che','Bing','Jie','Ti','Kong','Tui','Yan','Cuo','Zhou','Ju','Tian','Qian','Ken','Bai','Pa','Jie','Lu','Guai','Ming','Jie','Zhi','Dan','Meng','Can','Sao','Guan','Peng','Yuan','Nuo','Jian','Zheng','Jiu','Jian','Yu','Yan','Kui','Nan','Hong','Rou','Pi','Wei','Sai','Zou','Xuan','Miao','Ti','Nie','Cha','Shi','Zong','Zhen','Yi','Xun','Yong','Bian','Yang','Huan','Yan','Zan','An','Xu','Ya','Wo','Ke','Chuai','Ji','Ti','La','La','Chen','Kai','Jiu','Jiu','Tu','Jie','Hui','Gen','Chong','Xiao','Die','Xie','Yuan','Qian','Ye','Cha','Zha','Bei','Yao','Wei','Beng','Lan','Wen','Qin')


b=('Pan','Jie','Ye','Hui','Hui','Zai','Cheng','Yin','Wei','Hou','Jian','Yang','Lie','Si','Ji','Er','Xing','Fu','Sa','Se','Zhi','Yin','Wu','Xi','Kao','Zhu','Jiang','Luo','Luo','An','Dong','Ti','Mou','Lei','Yi','Mi','Quan','Jin','Po','Wei','Xiao','Xie','Hong','Xu','Su','Kuang','Tao','Qie','Ju','Er','Zhou','Ru','Ping','Xun','Xiong','Zhi','Guang','Huan','Ming','Huo','Wa','Qia','Pai','Wu','Qu','Liu','Yi','Jia','Jing','Qian','Jiang','Jiao','Zhen','Shi','Zhuo','Ce','Fa','Hui','Ji','Liu','Chan','Hun','Hu','Nong','Xun','Jin','Lie','Qiu','Wei','Zhe','Jun','Han','Bang','Mang','Zhuo','You','Xi','Bo','Dou','Huan','Hong','Yi','Pu','Ying','Lan','Hao','Lang','Han','Li','Geng','Fu','Wu','Lian','Chun','Feng','Yi','Yu','Tong','Lao','Hai','Jin','Jia','Chong','Jiong','Mei','Sui','Cheng','Pei','Xian','Shen','Tu','Kun','Ping','Nie','Han','Jing','Xiao','She','Nian','Tu','Yong','Xiao','Xian','Ting','E','Su','Tun','Juan','Cen','Ti','Li','Shui','Si','Lei','Shui','Tao','Du','Lao','Lai','Lian','Wei','Wo','Yun','Huan','Di','Heng','Run','Jian','Zhang','Se','Fu','Guan','Xing','Shou','Shuan','Ya','Chuo','Zhang','Ye','Kong','Wo','Han','Tuo','Dong','He','Wo','Ju','She','Liang','Hun','Ta','Zhuo','Dian','Qie','De','Juan','Zi','Xi','Xiao','Qi','Gu','Guo','Yan','Lin','Tang','Zhou','Peng','Hao','Chang','Shu','Qi','Fang','Zhi','Lu','Nao','Ju','Tao','Cong','Lei','Zhe','Ping','Fei','Song','Tian','Pi','Dan','Yu','Ni','Yu','Lu','Gan','Mi','Jing','Ling','Lun','Yin','Cui','Qu','Huai','Yu','Nian','Shen','Biao','Chun','Hu','Yuan','Lai','Hun','Qing','Yan','Qian','Tian','Miao','Zhi','Yin','Bo')


b=('Kui','Si','Liu','Nao','Huang','Pie','Sui','Fan','Qiao','Quan','Yang','Tang','Xiang','Jue','Jiao','Zun','Liao','Qie','Lao','Dui','Xin','Zan','Ji','Jian','Zhong','Deng','Ya','Ying','Dui','Jue','Nou','Zan','Pu','Tie','Fan','Cheng','Ding','Shan','Kai','Jian','Fei','Sui','Lu','Juan','Hui','Yu','Lian','Zhuo','Qiao','Jian','Zhuo','Lei','Bi','Tie','Huan','Ye','Duo','Guo','Dang','Ju','Fen','Da','Bei','Yi','Ai','Zong','Xun','Diao','Zhu','Heng','Zhui','Ji','Nie','He','Huo','Qing','Bin','Ying','Kui','Ning','Xu','Jian','Jian','Qian','Cha','Zhi','Mie','Li','Lei','Ji','Zuan','Kuang','Shang','Peng','La','Du','Shuo','Chuo','Lu','Biao','Bao','Lu','Xian','Kuan','Long','E','Lu','Xin','Jian','Lan','Bo','Jian','Yao','Chan','Xiang','Jian','Xi','Guan','Cang','Nie','Lei','Cuan','Qu','Pan','Luo','Zuan','Luan','Zao','Nie','Jue','Tang','Zhu','Lan','Jin','Ga','Yi','Zhen','Ding','Zhao','Po','Liao','Tu','Qian','Chuan','Shan','Sa','Fan','Diao','Men','Nu','Yang','Chai','Xing','Gai','Bu','Tai','Ju','Dun','Chao','Zhong','Na','Bei','Gang','Ban','Qian','Yao','Qin','Jun','Wu','Gou','Kang','Fang','Huo','Tou','Niu','Ba','Yu','Qian','Zheng','Qian','Gu','Bo','Ke','Po','Bu','Bo','Yue','Zuan','Mu','Tan','Jia','Dian','You','Tie','Bo','Ling','Shuo','Qian','Mao','Bao','Shi','Xuan','Ta','Bi','Ni','Pi','Duo','Xing','Kao','Lao','Er','Mang','Ya','You','Cheng','Jia','Ye','Nao','Zhi','Dang','Tong','Lu','Diao','Yin','Kai','Zha','Zhu','Xi','Ding','Diu','Xian','Hua','Quan','Sha','Ha','Diao','Ge','Ming','Zheng','Se','Jiao','Yi','Chan','Chong','Tang','An','Yin','Ru','Zhu','Lao','Pu','Wu','Lai','Te','Lian','Keng')


b=('geul','geulg','geulm','geulb','geuls','geult','geulp','geulh','geum','geub','geubs','geus','geuss','geung','geuj','geuch','geuk','geut','geup','geuh','gui','guig','guikk','guigs','guin','guinj','guinh','guid','guil','guilg','guilm','guilb','guils','guilt','guilp','guilh','guim','guib','guibs','guis','guiss','guing','guij','guich','guik','guit','guip','guih','gi','gig','gikk','gigs','gin','ginj','ginh','gid','gil','gilg','gilm','gilb','gils','gilt','gilp','gilh','gim','gib','gibs','gis','giss','ging','gij','gich','gik','git','gip','gih','kka','kkag','kkakk','kkags','kkan','kkanj','kkanh','kkad','kkal','kkalg','kkalm','kkalb','kkals','kkalt','kkalp','kkalh','kkam','kkab','kkabs','kkas','kkass','kkang','kkaj','kkach','kkak','kkat','kkap','kkah','kkae','kkaeg','kkaekk','kkaegs','kkaen','kkaenj','kkaenh','kkaed','kkael','kkaelg','kkaelm','kkaelb','kkaels','kkaelt','kkaelp','kkaelh','kkaem','kkaeb','kkaebs','kkaes','kkaess','kkaeng','kkaej','kkaech','kkaek','kkaet','kkaep','kkaeh','kkya','kkyag','kkyakk','kkyags','kkyan','kkyanj','kkyanh','kkyad','kkyal','kkyalg','kkyalm','kkyalb','kkyals','kkyalt','kkyalp','kkyalh','kkyam','kkyab','kkyabs','kkyas','kkyass','kkyang','kkyaj','kkyach','kkyak','kkyat','kkyap','kkyah','kkyae','kkyaeg','kkyaekk','kkyaegs','kkyaen','kkyaenj','kkyaenh','kkyaed','kkyael','kkyaelg','kkyaelm','kkyaelb','kkyaels','kkyaelt','kkyaelp','kkyaelh','kkyaem','kkyaeb','kkyaebs','kkyaes','kkyaess','kkyaeng','kkyaej','kkyaech','kkyaek','kkyaet','kkyaep','kkyaeh','kkeo','kkeog','kkeokk','kkeogs','kkeon','kkeonj','kkeonh','kkeod','kkeol','kkeolg','kkeolm','kkeolb','kkeols','kkeolt','kkeolp','kkeolh','kkeom','kkeob','kkeobs','kkeos','kkeoss','kkeong','kkeoj','kkeoch','kkeok','kkeot','kkeop','kkeoh','kke','kkeg','kkekk','kkegs','kken','kkenj','kkenh','kked','kkel','kkelg','kkelm','kkelb','kkels','kkelt','kkelp','kkelh','kkem','kkeb','kkebs','kkes','kkess','kkeng','kkej','kkech','kkek','kket','kkep','kkeh','kkyeo','kkyeog','kkyeokk','kkyeogs','kkyeon','kkyeonj','kkyeonh','kkyeod','kkyeol','kkyeolg','kkyeolm','kkyeolb')


b=('Ming','Sheng','Shi','Yun','Mian','Pan','Fang','Miao','Dan','Mei','Mao','Kan','Xian','Kou','Shi','Yang','Zheng','Yao','Shen','Huo','Da','Zhen','Kuang','Ju','Shen','Yi','Sheng','Mei','Mo','Zhu','Zhen','Zhen','Mian','Shi','Yuan','Die','Ni','Zi','Zi','Chao','Zha','Xuan','Bing','Mi','Long','Sui','Tong','Mi','Die','Di','Ne','Ming','Xuan','Chi','Kuang','Juan','Mou','Zhen','Tiao','Yang','Yan','Mo','Zhong','Mo','Zhe','Zheng','Mei','Suo','Shao','Han','Huan','Di','Cheng','Cuo','Juan','E','Man','Xian','Xi','Kun','Lai','Jian','Shan','Tian','Gun','Wan','Leng','Shi','Qiong','Lie','Ya','Jing','Zheng','Li','Lai','Sui','Juan','Shui','Sui','Du','Bi','Pi','Mu','Hun','Ni','Lu','Yi','Jie','Cai','Zhou','Yu','Hun','Ma','Xia','Xing','Hui','Gun','Zai','Chun','Jian','Mei','Du','Hou','Xuan','Tian','Kui','Gao','Rui','Mao','Xu','Fa','Wo','Miao','Chou','Kui','Mi','Weng','Kou','Dang','Chen','Ke','Sou','Xia','Qiong','Mo','Ming','Man','Shui','Ze','Zhang','Yi','Diao','Kou','Mo','Shun','Cong','Lou','Chi','Man','Piao','Cheng','Gui','Meng','Wan','Run','Pie','Xi','Qiao','Pu','Zhu','Deng','Shen','Shun','Liao','Che','Xian','Kan','Ye','Xu','Tong','Mou','Lin','Gui','Jian','Ye','Ai','Hui','Zhan','Jian','Gu','Zhao','Qu','Mei','Chou','Sao','Ning','Xun','Yao','Huo','Meng','Mian','Pin','Mian','Lei','Kuang','Jue','Xuan','Mian','Huo','Lu','Meng','Long','Guan','Man','Xi','Chu','Tang','Kan','Zhu','Mao','Jin','Jin','Yu','Shuo','Ze','Jue','Shi','Yi','Shen','Zhi','Hou','Shen','Ying','Ju','Zhou','Jiao','Cuo','Duan','Ai','Jiao','Zeng','Yue','Ba','Shi','Ding','Qi','Ji','Zi','Gan','Wu','Zhe','Ku','Gang','Xi','Fan','Kuang')


b=('dwaen','dwaenj','dwaenh','dwaed','dwael','dwaelg','dwaelm','dwaelb','dwaels','dwaelt','dwaelp','dwaelh','dwaem','dwaeb','dwaebs','dwaes','dwaess','dwaeng','dwaej','dwaech','dwaek','dwaet','dwaep','dwaeh','doe','doeg','doekk','doegs','doen','doenj','doenh','doed','doel','doelg','doelm','doelb','doels','doelt','doelp','doelh','doem','doeb','doebs','does','doess','doeng','doej','doech','doek','doet','doep','doeh','dyo','dyog','dyokk','dyogs','dyon','dyonj','dyonh','dyod','dyol','dyolg','dyolm','dyolb','dyols','dyolt','dyolp','dyolh','dyom','dyob','dyobs','dyos','dyoss','dyong','dyoj','dyoch','dyok','dyot','dyop','dyoh','du','dug','dukk','dugs','dun','dunj','dunh','dud','dul','dulg','dulm','dulb','duls','dult','dulp','dulh','dum','dub','dubs','dus','duss','dung','duj','duch','duk','dut','dup','duh','dwo','dwog','dwokk','dwogs','dwon','dwonj','dwonh','dwod','dwol','dwolg','dwolm','dwolb','dwols','dwolt','dwolp','dwolh','dwom','dwob','dwobs','dwos','dwoss','dwong','dwoj','dwoch','dwok','dwot','dwop','dwoh','dwe','dweg','dwekk','dwegs','dwen','dwenj','dwenh','dwed','dwel','dwelg','dwelm','dwelb','dwels','dwelt','dwelp','dwelh','dwem','dweb','dwebs','dwes','dwess','dweng','dwej','dwech','dwek','dwet','dwep','dweh','dwi','dwig','dwikk','dwigs','dwin','dwinj','dwinh','dwid','dwil','dwilg','dwilm','dwilb','dwils','dwilt','dwilp','dwilh','dwim','dwib','dwibs','dwis','dwiss','dwing','dwij','dwich','dwik','dwit','dwip','dwih','dyu','dyug','dyukk','dyugs','dyun','dyunj','dyunh','dyud','dyul','dyulg','dyulm','dyulb','dyuls','dyult','dyulp','dyulh','dyum','dyub','dyubs','dyus','dyuss','dyung','dyuj','dyuch','dyuk','dyut','dyup','dyuh','deu','deug','deukk','deugs','deun','deunj','deunh','deud','deul','deulg','deulm','deulb','deuls','deult','deulp','deulh','deum','deub','deubs','deus','deuss','deung','deuj','deuch','deuk','deut','deup','deuh','dui','duig','duikk','duigs','duin','duinj','duinh','duid')


b=('mil','milg','milm','milb','mils','milt','milp','milh','mim','mib','mibs','mis','miss','ming','mij','mich','mik','mit','mip','mih','ba','bag','bakk','bags','ban','banj','banh','bad','bal','balg','balm','balb','bals','balt','balp','balh','bam','bab','babs','bas','bass','bang','baj','bach','bak','bat','bap','bah','bae','baeg','baekk','baegs','baen','baenj','baenh','baed','bael','baelg','baelm','baelb','baels','baelt','baelp','baelh','baem','baeb','baebs','baes','baess','baeng','baej','baech','baek','baet','baep','baeh','bya','byag','byakk','byags','byan','byanj','byanh','byad','byal','byalg','byalm','byalb','byals','byalt','byalp','byalh','byam','byab','byabs','byas','byass','byang','byaj','byach','byak','byat','byap','byah','byae','byaeg','byaekk','byaegs','byaen','byaenj','byaenh','byaed','byael','byaelg','byaelm','byaelb','byaels','byaelt','byaelp','byaelh','byaem','byaeb','byaebs','byaes','byaess','byaeng','byaej','byaech','byaek','byaet','byaep','byaeh','beo','beog','beokk','beogs','beon','beonj','beonh','beod','beol','beolg','beolm','beolb','beols','beolt','beolp','beolh','beom','beob','beobs','beos','beoss','beong','beoj','beoch','beok','beot','beop','beoh','be','beg','bekk','begs','ben','benj','benh','bed','bel','belg','belm','belb','bels','belt','belp','belh','bem','beb','bebs','bes','bess','beng','bej','bech','bek','bet','bep','beh','byeo','byeog','byeokk','byeogs','byeon','byeonj','byeonh','byeod','byeol','byeolg','byeolm','byeolb','byeols','byeolt','byeolp','byeolh','byeom','byeob','byeobs','byeos','byeoss','byeong','byeoj','byeoch','byeok','byeot','byeop','byeoh','bye','byeg','byekk','byegs','byen','byenj','byenh','byed','byel','byelg','byelm','byelb','byels','byelt','byelp','byelh','byem','byeb','byebs','byes','byess','byeng','byej','byech','byek','byet','byep','byeh','bo','bog','bokk','bogs','bon','bonj','bonh','bod','bol','bolg','bolm','bolb')


b=('nyaess','nyaeng','nyaej','nyaech','nyaek','nyaet','nyaep','nyaeh','neo','neog','neokk','neogs','neon','neonj','neonh','neod','neol','neolg','neolm','neolb','neols','neolt','neolp','neolh','neom','neob','neobs','neos','neoss','neong','neoj','neoch','neok','neot','neop','neoh','ne','neg','nekk','negs','nen','nenj','nenh','ned','nel','nelg','nelm','nelb','nels','nelt','nelp','nelh','nem','neb','nebs','nes','ness','neng','nej','nech','nek','net','nep','neh','nyeo','nyeog','nyeokk','nyeogs','nyeon','nyeonj','nyeonh','nyeod','nyeol','nyeolg','nyeolm','nyeolb','nyeols','nyeolt','nyeolp','nyeolh','nyeom','nyeob','nyeobs','nyeos','nyeoss','nyeong','nyeoj','nyeoch','nyeok','nyeot','nyeop','nyeoh','nye','nyeg','nyekk','nyegs','nyen','nyenj','nyenh','nyed','nyel','nyelg','nyelm','nyelb','nyels','nyelt','nyelp','nyelh','nyem','nyeb','nyebs','nyes','nyess','nyeng','nyej','nyech','nyek','nyet','nyep','nyeh','no','nog','nokk','nogs','non','nonj','nonh','nod','nol','nolg','nolm','nolb','nols','nolt','nolp','nolh','nom','nob','nobs','nos','noss','nong','noj','noch','nok','not','nop','noh','nwa','nwag','nwakk','nwags','nwan','nwanj','nwanh','nwad','nwal','nwalg','nwalm','nwalb','nwals','nwalt','nwalp','nwalh','nwam','nwab','nwabs','nwas','nwass','nwang','nwaj','nwach','nwak','nwat','nwap','nwah','nwae','nwaeg','nwaekk','nwaegs','nwaen','nwaenj','nwaenh','nwaed','nwael','nwaelg','nwaelm','nwaelb','nwaels','nwaelt','nwaelp','nwaelh','nwaem','nwaeb','nwaebs','nwaes','nwaess','nwaeng','nwaej','nwaech','nwaek','nwaet','nwaep','nwaeh','noe','noeg','noekk','noegs','noen','noenj','noenh','noed','noel','noelg','noelm','noelb','noels','noelt','noelp','noelh','noem','noeb','noebs','noes','noess','noeng','noej','noech','noek','noet','noep','noeh','nyo','nyog','nyokk','nyogs','nyon','nyonj','nyonh','nyod','nyol','nyolg','nyolm','nyolb','nyols','nyolt','nyolp','nyolh','nyom','nyob','nyobs','nyos','nyoss','nyong','nyoj','nyoch')


b=('Cheng','Tiao','Zhi','Cui','Mei','Xie','Cui','Xie','Mai','Mai','Ji','Xie','Nin','Kuai','Sa','Zang','Qi','Nao','Mi','Nong','Luan','Wan','Bo','Wen','Wan','Xiu','Jiao','Jing','You','Heng','Cuo','Lie','Shan','Ting','Mei','Chun','Shen','Qian','De','Juan','Cu','Xiu','Xin','Tuo','Pao','Cheng','Nei','Pu','Dou','Tuo','Niao','Nao','Pi','Gu','Luo','Li','Lian','Zhang','Cui','Jie','Liang','Shui','Pi','Biao','Lun','Pian','Lei','Kui','Chui','Dan','Tian','Nei','Jing','Nai','La','Ye','Yan','Ren','Shen','Chuo','Fu','Fu','Ju','Fei','Qiang','Wan','Dong','Pi','Guo','Zong','Ding','Wo','Mei','Ni','Zhuan','Chi','Cou','Luo','Ou','Di','An','Xing','Nao','Shu','Shuan','Nan','Yun','Zhong','Rou','E','Sai','Tu','Yao','Jian','Wei','Jiao','Yu','Jia','Duan','Bi','Chang','Fu','Xian','Ni','Mian','Wa','Teng','Tui','Bang','Qian','Lu','Wa','Shou','Tang','Su','Zhui','Ge','Yi','Bo','Liao','Ji','Pi','Xie','Gao','Lu','Bin','Ou','Chang','Lu','Guo','Pang','Chuai','Biao','Jiang','Fu','Tang','Mo','Xi','Zhuan','Lu','Jiao','Ying','Lu','Zhi','Xue','Cun','Lin','Tong','Peng','Ni','Chuai','Liao','Cui','Gui','Xiao','Teng','Fan','Zhi','Jiao','Shan','Hu','Cui','Run','Xiang','Sui','Fen','Ying','Shan','Zhua','Dan','Kuai','Nong','Tun','Lian','Bi','Yong','Jue','Chu','Yi','Juan','La','Lian','Sao','Tun','Gu','Qi','Cui','Bin','Xun','Nao','Wo','Zang','Xian','Biao','Xing','Kuan','La','Yan','Lu','Huo','Za','Luo','Qu','Zang','Luan','Ni','Za','Chen','Qian','Wo','Guang','Zang','Lin','Guang','Zi','Jiao','Nie','Chou','Ji','Gao','Chou','Mian','Nie','Zhi','Zhi','Ge','Jian','Die','Zhi','Xiu','Tai','Zhen','Jiu','Xian','Yu','Cha')


b=('Di','Zhuang','Le','Lang','Chen','Cong','Li','Xiu','Qing','Shuang','Fan','Tong','Guan','Ze','Su','Lei','Lu','Liang','Mi','Lou','Chao','Su','Ke','Chu','Tang','Biao','Lu','Jiu','Zhe','Zha','Shu','Zhang','Man','Mo','Niao','Yang','Tiao','Peng','Zhu','Sha','Xi','Quan','Heng','Jian','Cong','Ji','Yan','Qiang','Xue','Ying','Er','Xun','Zhi','Qiao','Zui','Cong','Pu','Shu','Hua','Kui','Zhen','Zun','Yue','Shan','Xi','Chun','Dian','Fa','Gan','Mo','Wu','Qiao','Rao','Lin','Liu','Qiao','Xian','Run','Fan','Zhan','Tuo','Lao','Yun','Shun','Dun','Cheng','Tang','Meng','Ju','Cheng','Su','Jue','Jue','Dian','Hui','Ji','Nuo','Xiang','Tuo','Ning','Rui','Zhu','Tong','Zeng','Fen','Qiong','Ran','Heng','Qian','Gu','Liu','Lao','Gao','Chu','Xi','Sheng','Zi','San','Ji','Dou','Jing','Lu','Jian','Chu','Yuan','Ta','Shu','Jiang','Tan','Lin','Nong','Yin','Xi','Hui','Shan','Zui','Xuan','Cheng','Gan','Ju','Zui','Yi','Qin','Pu','Yan','Lei','Feng','Hui','Dang','Ji','Sui','Bo','Ping','Cheng','Chu','Zhua','Gui','Ji','Jie','Jia','Qing','Zhai','Jian','Qiang','Dao','Yi','Biao','Song','She','Lin','Li','Cha','Meng','Yin','Tao','Tai','Mian','Qi','Tuan','Bin','Huo','Ji','Qian','Ni','Ning','Yi','Gao','Kan','Yin','Nou','Qing','Yan','Qi','Mi','Zhao','Gui','Chun','Ji','Kui','Po','Deng','Chu','Ge','Mian','You','Zhi','Huang','Qian','Lei','Lei','Sa','Lu','Li','Cuan','Lu','Mie','Hui','Ou','Lu','Zhi','Gao','Du','Yuan','Li','Fei','Zhuo','Sou','Lian','Jiang','Chu','Qing','Zhu','Lu','Yan','Li','Zhu','Chen','Jie','E','Su','Huai','Nie','Yu','Long','Lai','Jiao','Xian','Gui','Ju','Xiao','Ling','Ying','Jian','Yin','You','Ying')


b=('Tui','Song','Shi','Tao','Pang','Hou','Ni','Dun','Jiong','Xuan','Xun','Bu','You','Xiao','Qiu','Tou','Zhu','Qiu','Di','Di','Tu','Jing','Ti','Dou','Yi','Zhe','Tong','Guang','Wu','Shi','Cheng','Su','Zao','Qun','Feng','Lian','Suo','Hui','Li','Gu','Lai','Ben','Cuo','Jue','Beng','Huan','Dai','Lu','You','Zhou','Jin','Yu','Chuo','Kui','Wei','Ti','Yi','Da','Yuan','Luo','Bi','Nuo','Yu','Dang','Sui','Dun','Sui','Yan','Chuan','Chi','Ti','Yu','Shi','Zhen','You','Yun','E','Bian','Guo','E','Xia','Huang','Qiu','Dao','Da','Wei','Nan','Yi','Gou','Yao','Chou','Liu','Xun','Ta','Di','Chi','Yuan','Su','Ta','Qian','Ma','Yao','Guan','Zhang','Ao','Shi','Ca','Chi','Su','Zao','Zhe','Dun','Di','Lou','Chi','Cuo','Lin','Zun','Rao','Qian','Xuan','Yu','Yi','E','Liao','Ju','Shi','Bi','Yao','Mai','Xie','Sui','Hai','Zhan','Teng','Er','Miao','Bian','Bian','La','Li','Yuan','Yao','Luo','Li','Yi','Ting','Deng','Qi','Yong','Shan','Han','Yu','Mang','Ru','Qiong','Xi','Kuang','Fu','Kang','Bin','Fang','Xing','Na','Xin','Shen','Bang','Yuan','Cun','Huo','Xie','Bang','Wu','Ju','You','Han','Tai','Qiu','Bi','Pi','Bing','Shao','Bei','Wa','Di','Zou','Ye','Lin','Kuang','Gui','Zhu','Shi','Ku','Yu','Gai','He','Qie','Zhi','Ji','Huan','Hou','Xing','Jiao','Xi','Gui','Nuo','Lang','Jia','Kuai','Zheng','Lang','Yun','Yan','Cheng','Dou','Xi','Lu','Fu','Wu','Fu','Gao','Hao','Lang','Jia','Geng','Jun','Ying','Bo','Xi','Bei','Li','Yun','Bu','Xiao','Qi','Pi','Qing','Guo','Zhou','Tan','Zou','Ping','Lai','Ni','Chen','You','Bu','Xiang','Dan','Ju','Yong','Qiao','Yi','Dou','Yan','Mei')


b=('Huai','Tai','Song','Wu','Ou','Chang','Chuang','Ju','Yi','Bao','Chao','Min','Pei','Zuo','Zen','Yang','Ju','Ban','Nu','Nao','Zheng','Pa','Bu','Tie','Hu','Hu','Ju','Da','Lian','Si','Chou','Di','Dai','Yi','Tu','You','Fu','Ji','Peng','Xing','Yuan','Ni','Guai','Fu','Xi','Bi','You','Qie','Xuan','Cong','Bing','Huang','Xu','Chu','Bi','Shu','Xi','Tan','Yong','Zong','Dui','Mo','Zhi','Yi','Shi','Nen','Xun','Shi','Xi','Lao','Heng','Kuang','Mou','Zhi','Xie','Lian','Tiao','Huang','Die','Hao','Kong','Gui','Heng','Xi','Jiao','Shu','Si','Hu','Qiu','Yang','Hui','Hui','Chi','Jia','Yi','Xiong','Guai','Lin','Hui','Zi','Xu','Chi','Shang','Nu','Hen','En','Ke','Dong','Tian','Gong','Quan','Xi','Qia','Yue','Peng','Ken','De','Hui','E','Xiao','Tong','Yan','Kai','Ce','Nao','Yun','Mang','Yong','Yong','Yuan','Pi','Kun','Qiao','Yue','Yu','Tu','Jie','Xi','Zhe','Lin','Ti','Han','Hao','Qie','Ti','Bu','Yi','Qian','Hui','Xi','Bei','Man','Yi','Heng','Song','Quan','Cheng','Kui','Wu','Wu','You','Li','Liang','Huan','Cong','Yi','Yue','Li','Nin','Nao','E','Que','Xuan','Qian','Wu','Min','Cong','Fei','Bei','De','Cui','Chang','Men','San','Ji','Guan','Guan','Xing','Dao','Qi','Kong','Tian','Lun','Xi','Kan','Gun','Ni','Qing','Chou','Dun','Guo','Zhan','Jing','Wan','Yuan','Jin','Ji','Lan','Yu','Huo','He','Quan','Tan','Ti','Ti','Nie','Wang','Chuo','Hu','Hun','Xi','Chang','Xin','Wei','Hui','E','Suo','Zong','Jian','Yong','Dian','Ju','Can','Cheng','De','Bei','Qie','Can','Dan','Guan','Duo','Nao','Yun','Xiang','Zhui','Die','Huang','Chun','Qiong','Re','Xing','Ce','Bian','Min','Zong','Ti')


b=('Yan','Yan','Ding','Fu','Qiu','Qiu','Jiao','Hong','Ji','Fan','Xun','Diao','Hong','Chai','Tao','Xu','Jie','Yi','Ren','Xun','Yin','Shan','Qi','Tuo','Ji','Xun','Yin','E','Fen','Ya','Yao','Song','Shen','Yin','Xin','Jue','Xiao','Ne','Chen','You','Zhi','Xiong','Fang','Xin','Chao','She','Yan','Sa','Zhun','Xu','Yi','Yi','Su','Chi','He','Shen','He','Xu','Zhen','Zhu','Zheng','Gou','Zi','Zi','Zhan','Gu','Fu','Jian','Die','Ling','Di','Yang','Li','Nao','Pan','Zhou','Gan','Yi','Ju','Yao','Zha','Yi','Yi','Qu','Zhao','Ping','Bi','Xiong','Qu','Ba','Da','Zu','Tao','Zhu','Ci','Zhe','Yong','Xu','Xun','Yi','Huang','He','Shi','Cha','Xiao','Shi','Hen','Cha','Gou','Gui','Quan','Hui','Jie','Hua','Gai','Xiang','Wei','Shen','Zhou','Tong','Mi','Zhan','Ming','E','Hui','Yan','Xiong','Gua','Er','Bing','Tiao','Yi','Lei','Zhu','Kuang','Kua','Wu','Yu','Teng','Ji','Zhi','Ren','Cu','Lang','E','Kuang','Ei','Shi','Ting','Dan','Bei','Chan','You','Keng','Qiao','Qin','Shua','An','Yu','Xiao','Cheng','Jie','Xian','Wu','Wu','Gao','Song','Bu','Hui','Jing','Shuo','Zhen','Shuo','Du','Hua','Chang','Shui','Jie','Ke','Qu','Cong','Xiao','Sui','Wang','Xian','Fei','Chi','Ta','Yi','Ni','Yin','Diao','Pi','Zhuo','Chan','Chen','Zhun','Ji','Qi','Tan','Zhui','Wei','Ju','Qing','Dong','Zheng','Ze','Zou','Qian','Zhuo','Liang','Jian','Chu','Hao','Lun','Shen','Biao','Hua','Pian','Yu','Die','Xu','Pian','Shi','Xuan','Shi','Hun','Hua','E','Zhong','Di','Xie','Fu','Pu','Ting','Jian','Qi','Yu','Zi','Zhuan','Xi','Hui','Yin','An','Xian','Nan','Chen','Feng','Zhu','Yang','Yan','Huang','Xuan','Ge','Nuo','Qi')


b=('Lu','Mu','Mao','Tong','Rong','Chang','Pu','Lu','Zhan','Sao','Zhan','Meng','Lu','Qu','Die','Shi','Di','Min','Jue','Mang','Qi','Pie','Nai','Qi','Dao','Xian','Chuan','Fen','Yang','Nei','Bin','Fu','Shen','Dong','Qing','Qi','Yin','Xi','Hai','Yang','An','Ya','Ke','Qing','Ya','Dong','Dan','Lu','Qing','Yang','Yun','Yun','Shui','Shui','Zheng','Bing','Yong','Dang','Shui','Le','Ni','Tun','Fan','Gui','Ting','Zhi','Qiu','Bin','Ze','Mian','Cuan','Hui','Diao','Han','Cha','Zhuo','Chuan','Wan','Fan','Da','Xi','Tuo','Mang','Qiu','Qi','Shan','Pin','Han','Qian','Wu','Wu','Xun','Si','Ru','Gong','Jiang','Chi','Wu','Tu','Jiu','Tang','Zhi','Zhi','Qian','Mi','Gu','Wang','Jing','Jing','Rui','Jun','Hong','Tai','Quan','Ji','Bian','Bian','Gan','Wen','Zhong','Fang','Xiong','Jue','Hu','Niu','Qi','Fen','Xu','Xu','Qin','Yi','Wo','Yun','Yuan','Hang','Yan','Chen','Chen','Dan','You','Dun','Hu','Huo','Qi','Mu','Nu','Mei','Da','Mian','Mi','Chong','Pang','Bi','Sha','Zhi','Pei','Pan','Zhui','Za','Gou','Liu','Mei','Ze','Feng','Ou','Li','Lun','Cang','Feng','Wei','Hu','Mo','Mei','Shu','Ju','Za','Tuo','Tuo','Tuo','He','Li','Mi','Yi','Fa','Fei','You','Tian','Zhi','Zhao','Gu','Zhan','Yan','Si','Kuang','Jiong','Ju','Xie','Qiu','Yi','Jia','Zhong','Quan','Po','Hui','Mi','Ben','Ze','Zhu','Le','You','Gu','Hong','Gan','Fa','Mao','Si','Hu','Ping','Ci','Fan','Zhi','Su','Ning','Cheng','Ling','Pao','Bo','Qi','Si','Ni','Ju','Sa','Zhu','Sheng','Lei','Xuan','Jue','Fu','Pan','Min','Tai','Yang','Ji','Yong','Guan','Beng','Xue','Long','Lu','Dan','Luo','Xie','Po','Ze','Jing','Yin')


b=('it','ix','i','ip','iet','iex','ie','iep','at','ax','a','ap','uox','uo','uop','ot','ox','o','op','ex','e','w','bit','bix','bi','bip','biet','biex','bie','biep','bat','bax','ba','bap','buox','buo','buop','bot','box','bo','bop','bex','be','bep','but','bux','bu','bup','burx','bur','byt','byx','by','byp','byrx','byr','pit','pix','pi','pip','piex','pie','piep','pat','pax','pa','pap','puox','puo','puop','pot','pox','po','pop','put','pux','pu','pup','purx','pur','pyt','pyx','py','pyp','pyrx','pyr','bbit','bbix','bbi','bbip','bbiet','bbiex','bbie','bbiep','bbat','bbax','bba','bbap','bbuox','bbuo','bbuop','bbot','bbox','bbo','bbop','bbex','bbe','bbep','bbut','bbux','bbu','bbup','bburx','bbur','bbyt','bbyx','bby','bbyp','nbit','nbix','nbi','nbip','nbiex','nbie','nbiep','nbat','nbax','nba','nbap','nbot','nbox','nbo','nbop','nbut','nbux','nbu','nbup','nburx','nbur','nbyt','nbyx','nby','nbyp','nbyrx','nbyr','hmit','hmix','hmi','hmip','hmiex','hmie','hmiep','hmat','hmax','hma','hmap','hmuox','hmuo','hmuop','hmot','hmox','hmo','hmop','hmut','hmux','hmu','hmup','hmurx','hmur','hmyx','hmy','hmyp','hmyrx','hmyr','mit','mix','mi','mip','miex','mie','miep','mat','max','ma','map','muot','muox','muo','muop','mot','mox','mo','mop','mex','me','mut','mux','mu','mup','murx','mur','myt','myx','my','myp','fit','fix','fi','fip','fat','fax','fa','fap','fox','fo','fop','fut','fux','fu','fup','furx','fur','fyt','fyx','fy','fyp','vit','vix','vi','vip','viet','viex','vie','viep','vat','vax','va','vap','vot','vox','vo','vop','vex','vep','vut','vux','vu','vup','vurx','vur','vyt','vyx','vy','vyp','vyrx','vyr')


b=('ga','gag','gakk','gags','gan','ganj','ganh','gad','gal','galg','galm','galb','gals','galt','galp','galh','gam','gab','gabs','gas','gass','gang','gaj','gach','gak','gat','gap','gah','gae','gaeg','gaekk','gaegs','gaen','gaenj','gaenh','gaed','gael','gaelg','gaelm','gaelb','gaels','gaelt','gaelp','gaelh','gaem','gaeb','gaebs','gaes','gaess','gaeng','gaej','gaech','gaek','gaet','gaep','gaeh','gya','gyag','gyakk','gyags','gyan','gyanj','gyanh','gyad','gyal','gyalg','gyalm','gyalb','gyals','gyalt','gyalp','gyalh','gyam','gyab','gyabs','gyas','gyass','gyang','gyaj','gyach','gyak','gyat','gyap','gyah','gyae','gyaeg','gyaekk','gyaegs','gyaen','gyaenj','gyaenh','gyaed','gyael','gyaelg','gyaelm','gyaelb','gyaels','gyaelt','gyaelp','gyaelh','gyaem','gyaeb','gyaebs','gyaes','gyaess','gyaeng','gyaej','gyaech','gyaek','gyaet','gyaep','gyaeh','geo','geog','geokk','geogs','geon','geonj','geonh','geod','geol','geolg','geolm','geolb','geols','geolt','geolp','geolh','geom','geob','geobs','geos','geoss','geong','geoj','geoch','geok','geot','geop','geoh','ge','geg','gekk','gegs','gen','genj','genh','ged','gel','gelg','gelm','gelb','gels','gelt','gelp','gelh','gem','geb','gebs','ges','gess','geng','gej','gech','gek','get','gep','geh','gyeo','gyeog','gyeokk','gyeogs','gyeon','gyeonj','gyeonh','gyeod','gyeol','gyeolg','gyeolm','gyeolb','gyeols','gyeolt','gyeolp','gyeolh','gyeom','gyeob','gyeobs','gyeos','gyeoss','gyeong','gyeoj','gyeoch','gyeok','gyeot','gyeop','gyeoh','gye','gyeg','gyekk','gyegs','gyen','gyenj','gyenh','gyed','gyel','gyelg','gyelm','gyelb','gyels','gyelt','gyelp','gyelh','gyem','gyeb','gyebs','gyes','gyess','gyeng','gyej','gyech','gyek','gyet','gyep','gyeh','go','gog','gokk','gogs','gon','gonj','gonh','god','gol','golg','golm','golb','gols','golt','golp','golh','gom','gob','gobs','gos','goss','gong','goj','goch','gok','got','gop','goh','gwa','gwag','gwakk','gwags')


b=('Kai','Bian','Yi','Qi','Nong','Fen','Ju','Yan','Yi','Zang','Bi','Yi','Yi','Er','San','Shi','Er','Shi','Shi','Gong','Diao','Yin','Hu','Fu','Hong','Wu','Tui','Chi','Jiang','Ba','Shen','Di','Zhang','Jue','Tao','Fu','Di','Mi','Xian','Hu','Chao','Nu','Jing','Zhen','Yi','Mi','Quan','Wan','Shao','Ruo','Xuan','Jing','Diao','Zhang','Jiang','Qiang','Peng','Dan','Qiang','Bi','Bi','She','Dan','Jian','Gou','Ge','Fa','Bi','Kou','Jian','Bie','Xiao','Dan','Guo','Jiang','Hong','Mi','Guo','Wan','Jue','Ji','Ji','Gui','Dang','Lu','Lu','Tuan','Hui','Zhi','Hui','Hui','Yi','Yi','Yi','Yi','Yue','Yue','Shan','Xing','Wen','Tong','Yan','Yan','Yu','Chi','Cai','Biao','Diao','Bin','Peng','Yong','Piao','Zhang','Ying','Chi','Chi','Zhuo','Tuo','Ji','Fang','Zhong','Yi','Wang','Che','Bi','Di','Ling','Fu','Wang','Zheng','Cu','Wang','Jing','Dai','Xi','Xun','Hen','Yang','Huai','Lu','Hou','Wang','Cheng','Zhi','Xu','Jing','Tu','Cong','Zhi','Lai','Cong','De','Pai','Xi','Dong','Ji','Chang','Zhi','Cong','Zhou','Lai','Yu','Xie','Jie','Jian','Shi','Jia','Bian','Huang','Fu','Xun','Wei','Pang','Yao','Wei','Xi','Zheng','Piao','Ti','De','Zheng','Zheng','Bie','De','Chong','Che','Jiao','Hui','Jiao','Hui','Mei','Long','Xiang','Bao','Qu','Xin','Xin','Bi','Yi','Le','Ren','Dao','Ding','Gai','Ji','Ren','Ren','Chan','Tan','Te','Te','Gan','Qi','Shi','Cun','Zhi','Wang','Mang','Xi','Fan','Ying','Tian','Min','Wen','Zhong','Chong','Wu','Ji','Wu','Xi','Jia','You','Wan','Cong','Song','Kuai','Yu','Bian','Zhi','Qi','Cui','Chen','Tai','Tun','Qian','Nian','Hun','Xiong','Niu','Kuang','Xian','Xin','Kang','Hu','Kai','Fen')


b=('hwen','hwenj','hwenh','hwed','hwel','hwelg','hwelm','hwelb','hwels','hwelt','hwelp','hwelh','hwem','hweb','hwebs','hwes','hwess','hweng','hwej','hwech','hwek','hwet','hwep','hweh','hwi','hwig','hwikk','hwigs','hwin','hwinj','hwinh','hwid','hwil','hwilg','hwilm','hwilb','hwils','hwilt','hwilp','hwilh','hwim','hwib','hwibs','hwis','hwiss','hwing','hwij','hwich','hwik','hwit','hwip','hwih','hyu','hyug','hyukk','hyugs','hyun','hyunj','hyunh','hyud','hyul','hyulg','hyulm','hyulb','hyuls','hyult','hyulp','hyulh','hyum','hyub','hyubs','hyus','hyuss','hyung','hyuj','hyuch','hyuk','hyut','hyup','hyuh','heu','heug','heukk','heugs','heun','heunj','heunh','heud','heul','heulg','heulm','heulb','heuls','heult','heulp','heulh','heum','heub','heubs','heus','heuss','heung','heuj','heuch','heuk','heut','heup','heuh','hui','huig','huikk','huigs','huin','huinj','huinh','huid','huil','huilg','huilm','huilb','huils','huilt','huilp','huilh','huim','huib','huibs','huis','huiss','huing','huij','huich','huik','huit','huip','huih','hi','hig','hikk','higs','hin','hinj','hinh','hid','hil','hilg','hilm','hilb','hils','hilt','hilp','hilh','him','hib','hibs','his','hiss','hing','hij','hich','hik','hit','hip','hih')


b=('Hu','Xi','Shu','He','Xun','Ku','Juan','Xiao','Xi','Yan','Han','Zhuang','Jun','Di','Xie','Ji','Wu','Yan','Lu','Han','Yan','Huan','Men','Ju','Dao','Bei','Fen','Lin','Kun','Hun','Tun','Xi','Cui','Wu','Hong','Chao','Fu','Wo','Jiao','Cong','Feng','Ping','Qiong','Ruo','Xi','Qiong','Xin','Chao','Yan','Yan','Yi','Jue','Yu','Gang','Ran','Pi','Xiong','Gang','Sheng','Chang','Shao','Xiong','Nian','Geng','Wei','Chen','He','Kui','Zhong','Duan','Xia','Hui','Feng','Lian','Xuan','Xing','Huang','Jiao','Jian','Bi','Ying','Zhu','Wei','Tuan','Shan','Xi','Nuan','Nuan','Chan','Yan','Jiong','Jiong','Yu','Mei','Sha','Wei','Zha','Jin','Qiong','Rou','Mei','Huan','Xu','Zhao','Wei','Fan','Qiu','Sui','Yang','Lie','Zhu','Jie','Zao','Gua','Bao','Hu','Yun','Nan','Shi','Liang','Bian','Gou','Tui','Tang','Chao','Shan','En','Bo','Huang','Xie','Xi','Wu','Xi','Yun','He','He','Xi','Yun','Xiong','Nai','Shan','Qiong','Yao','Xun','Mi','Lian','Ying','Wu','Rong','Gong','Yan','Qiang','Liu','Xi','Bi','Biao','Cong','Lu','Jian','Shu','Yi','Lou','Peng','Sui','Yi','Teng','Jue','Zong','Yun','Hu','Yi','Zhi','Ao','Wei','Liu','Han','Ou','Re','Jiong','Man','Kun','Shang','Cuan','Zeng','Jian','Xi','Xi','Xi','Yi','Xiao','Chi','Huang','Chan','Ye','Tan','Ran','Yan','Xun','Qiao','Jun','Deng','Dun','Shen','Jiao','Fen','Si','Liao','Yu','Lin','Tong','Shao','Fen','Fan','Yan','Xun','Lan','Mei','Tang','Yi','Jiong','Men','Jing','Jiao','Ying','Yu','Yi','Xue','Lan','Tai','Zao','Can','Sui','Xi','Que','Zong','Lian','Hui','Zhu','Xie','Ling','Wei','Yi','Xie','Zhao','Hui','Da','Nong','Lan','Ru','Xian','He','Xun','Jin','Chou','Dao','Yao')


b=('Hai','Ren','Tian','Jiao','Jia','Bing','Yao','Tong','Ci','Xiang','Yang','Juan','Er','Yan','Le','Xi','Can','Bo','Nei','E','Bu','Jun','Dou','Su','Yu','Shi','Yao','Hun','Guo','Shi','Jian','Zhui','Bing','Xian','Bu','Ye','Tan','Fei','Zhang','Wei','Guan','E','Nuan','Yun','Hu','Huang','Tie','Hui','Jian','Hou','Ai','Tang','Fen','Wei','Gu','Cha','Song','Tang','Bo','Gao','Xi','Kui','Liu','Sou','Tao','Ye','Wen','Mo','Tang','Man','Bi','Yu','Xiu','Jin','San','Kui','Zhuan','Shan','Chi','Dan','Yi','Ji','Rao','Cheng','Yong','Tao','Wei','Xiang','Zhan','Fen','Hai','Meng','Yan','Mo','Chan','Xiang','Luo','Zan','Nang','Shi','Ding','Ji','Tuo','Tang','Tun','Xi','Ren','Yu','Chi','Fan','Yin','Jian','Shi','Bao','Si','Duo','Yi','Er','Rao','Xiang','He','Le','Jiao','Xi','Bing','Bo','Dou','E','Yu','Nei','Jun','Guo','Hun','Xian','Guan','Cha','Kui','Gu','Sou','Chan','Ye','Mo','Bo','Liu','Xiu','Jin','Man','San','Zhuan','Nang','Shou','Kui','Guo','Xiang','Fen','Bo','Ni','Bi','Bo','Tu','Han','Fei','Jian','An','Ai','Fu','Xian','Yun','Xin','Fen','Pin','Xin','Ma','Yu','Feng','Han','Di','Tuo','Zhe','Chi','Xun','Zhu','Zhi','Pei','Xin','Ri','Sa','Yun','Wen','Zhi','Dan','Lu','You','Bo','Bao','Jue','Tuo','Yi','Qu','Wen','Qu','Jiong','Po','Zhao','Yuan','Pei','Zhou','Ju','Zhu','Nu','Ju','Pi','Zang','Jia','Ling','Zhen','Tai','Fu','Yang','Shi','Bi','Tuo','Tuo','Si','Liu','Ma','Pian','Tao','Zhi','Rong','Teng','Dong','Xun','Quan','Shen','Jiong','Er','Hai','Bo','Zhu','Yin','Luo','Zhou','Dan','Hai','Liu','Ju','Song','Qin','Mang','Lang','Han','Tu','Xuan','Tui','Jun')


b=('Hu','Qi','He','Cui','Tao','Chun','Bi','Chang','Huan','Fei','Lai','Qi','Meng','Ping','Wei','Dan','Sha','Huan','Yan','Yi','Tiao','Qi','Wan','Ce','Nai','Zhen','Tuo','Jiu','Tie','Luo','Bi','Yi','Pan','Bo','Pao','Ding','Ying','Ying','Ying','Xiao','Sa','Qiu','Ke','Xiang','Wan','Yu','Yu','Fu','Lian','Xuan','Xuan','Nan','Ce','Wo','Chun','Xiao','Yu','Bian','Mao','An','E','Luo','Ying','Kuo','Kuo','Jiang','Mian','Zuo','Zuo','Zu','Bao','Rou','Xi','Ye','An','Qu','Jian','Fu','Lu','Jing','Pen','Feng','Hong','Hong','Hou','Yan','Tu','Zhe','Zi','Xiang','Ren','Ge','Qia','Qing','Mi','Huang','Shen','Pu','Gai','Dong','Zhou','Jian','Wei','Bo','Wei','Pa','Ji','Hu','Zang','Jia','Duan','Yao','Sui','Cong','Quan','Wei','Zhen','Kui','Ting','Hun','Xi','Shi','Qi','Lan','Zong','Yao','Yuan','Mei','Yun','Shu','Di','Zhuan','Guan','Ran','Xue','Chan','Kai','Kui','Hua','Jiang','Lou','Wei','Pai','You','Sou','Yin','Shi','Chun','Shi','Yun','Zhen','Lang','Ru','Meng','Li','Que','Suan','Yuan','Li','Ju','Xi','Bang','Chu','Xu','Tu','Liu','Huo','Dian','Qian','Zu','Po','Cuo','Yuan','Chu','Yu','Kuai','Pan','Pu','Pu','Na','Shuo','Xi','Fen','Yun','Zheng','Jian','Ji','Ruo','Cang','En','Mi','Hao','Sun','Zhen','Ming','Sou','Xu','Liu','Xi','Gu','Lang','Rong','Weng','Gai','Cuo','Shi','Tang','Luo','Ru','Suo','Xuan','Bei','Yao','Gui','Bi','Zong','Gun','Zuo','Tiao','Ce','Pei','Lan','Dan','Ji','Li','Shen','Lang','Yu','Ling','Ying','Mo','Diao','Tiao','Mao','Tong','Chu','Peng','An','Lian','Cong','Xi','Ping','Qiu','Jin','Chun','Jie','Wei','Tui','Cao','Yu','Yi','Zi','Liao','Bi','Lu','Xu')


b=('Yao','Lao','Lao','Kao','Mao','Zhe','Qi','Gou','Gou','Gou','Die','Die','Er','Shua','Ruan','Nai','Nai','Duan','Lei','Ting','Zi','Geng','Chao','Hao','Yun','Ba','Pi','Yi','Si','Qu','Jia','Ju','Huo','Chu','Lao','Lun','Ji','Tang','Ou','Lou','Nou','Jiang','Pang','Zha','Lou','Ji','Lao','Huo','You','Mo','Huai','Er','Yi','Ding','Ye','Da','Song','Qin','Yun','Chi','Dan','Dan','Hong','Geng','Zhi','Pan','Nie','Dan','Zhen','Che','Ling','Zheng','You','Wa','Liao','Long','Zhi','Ning','Tiao','Er','Ya','Tie','Gua','Xu','Lian','Hao','Sheng','Lie','Pin','Jing','Ju','Bi','Di','Guo','Wen','Xu','Ping','Cong','Ding','Ni','Ting','Ju','Cong','Kui','Lian','Kui','Cong','Lian','Weng','Kui','Lian','Lian','Cong','Ao','Sheng','Song','Ting','Kui','Nie','Zhi','Dan','Ning','Qie','Ni','Ting','Ting','Long','Yu','Yu','Zhao','Si','Su','Yi','Su','Si','Zhao','Zhao','Rou','Yi','Le','Ji','Qiu','Ken','Cao','Ge','Bo','Huan','Huang','Chi','Ren','Xiao','Ru','Zhou','Yuan','Du','Gang','Rong','Gan','Cha','Wo','Chang','Gu','Zhi','Han','Fu','Fei','Fen','Pei','Pang','Jian','Fang','Zhun','You','Na','Ang','Ken','Ran','Gong','Yu','Wen','Yao','Qi','Pi','Qian','Xi','Xi','Fei','Ken','Jing','Tai','Shen','Zhong','Zhang','Xie','Shen','Wei','Zhou','Die','Dan','Fei','Ba','Bo','Qu','Tian','Bei','Gua','Tai','Zi','Fei','Zhi','Ni','Ping','Zi','Fu','Pang','Zhen','Xian','Zuo','Pei','Jia','Sheng','Zhi','Bao','Mu','Qu','Hu','Ke','Chi','Yin','Xu','Yang','Long','Dong','Ka','Lu','Jing','Nu','Yan','Pang','Kua','Yi','Guang','Hai','Ge','Dong','Chi','Jiao','Xiong','Xiong','Er','An','Heng','Pian','Neng','Zi','Gui')


b=('toels','toelt','toelp','toelh','toem','toeb','toebs','toes','toess','toeng','toej','toech','toek','toet','toep','toeh','tyo','tyog','tyokk','tyogs','tyon','tyonj','tyonh','tyod','tyol','tyolg','tyolm','tyolb','tyols','tyolt','tyolp','tyolh','tyom','tyob','tyobs','tyos','tyoss','tyong','tyoj','tyoch','tyok','tyot','tyop','tyoh','tu','tug','tukk','tugs','tun','tunj','tunh','tud','tul','tulg','tulm','tulb','tuls','tult','tulp','tulh','tum','tub','tubs','tus','tuss','tung','tuj','tuch','tuk','tut','tup','tuh','two','twog','twokk','twogs','twon','twonj','twonh','twod','twol','twolg','twolm','twolb','twols','twolt','twolp','twolh','twom','twob','twobs','twos','twoss','twong','twoj','twoch','twok','twot','twop','twoh','twe','tweg','twekk','twegs','twen','twenj','twenh','twed','twel','twelg','twelm','twelb','twels','twelt','twelp','twelh','twem','tweb','twebs','twes','twess','tweng','twej','twech','twek','twet','twep','tweh','twi','twig','twikk','twigs','twin','twinj','twinh','twid','twil','twilg','twilm','twilb','twils','twilt','twilp','twilh','twim','twib','twibs','twis','twiss','twing','twij','twich','twik','twit','twip','twih','tyu','tyug','tyukk','tyugs','tyun','tyunj','tyunh','tyud','tyul','tyulg','tyulm','tyulb','tyuls','tyult','tyulp','tyulh','tyum','tyub','tyubs','tyus','tyuss','tyung','tyuj','tyuch','tyuk','tyut','tyup','tyuh','teu','teug','teukk','teugs','teun','teunj','teunh','teud','teul','teulg','teulm','teulb','teuls','teult','teulp','teulh','teum','teub','teubs','teus','teuss','teung','teuj','teuch','teuk','teut','teup','teuh','tui','tuig','tuikk','tuigs','tuin','tuinj','tuinh','tuid','tuil','tuilg','tuilm','tuilb','tuils','tuilt','tuilp','tuilh','tuim','tuib','tuibs','tuis','tuiss','tuing','tuij','tuich','tuik','tuit','tuip','tuih','ti','tig','tikk','tigs','tin','tinj','tinh','tid','til','tilg','tilm','tilb','tils','tilt','tilp','tilh')


b=('ppwok','ppwot','ppwop','ppwoh','ppwe','ppweg','ppwekk','ppwegs','ppwen','ppwenj','ppwenh','ppwed','ppwel','ppwelg','ppwelm','ppwelb','ppwels','ppwelt','ppwelp','ppwelh','ppwem','ppweb','ppwebs','ppwes','ppwess','ppweng','ppwej','ppwech','ppwek','ppwet','ppwep','ppweh','ppwi','ppwig','ppwikk','ppwigs','ppwin','ppwinj','ppwinh','ppwid','ppwil','ppwilg','ppwilm','ppwilb','ppwils','ppwilt','ppwilp','ppwilh','ppwim','ppwib','ppwibs','ppwis','ppwiss','ppwing','ppwij','ppwich','ppwik','ppwit','ppwip','ppwih','ppyu','ppyug','ppyukk','ppyugs','ppyun','ppyunj','ppyunh','ppyud','ppyul','ppyulg','ppyulm','ppyulb','ppyuls','ppyult','ppyulp','ppyulh','ppyum','ppyub','ppyubs','ppyus','ppyuss','ppyung','ppyuj','ppyuch','ppyuk','ppyut','ppyup','ppyuh','ppeu','ppeug','ppeukk','ppeugs','ppeun','ppeunj','ppeunh','ppeud','ppeul','ppeulg','ppeulm','ppeulb','ppeuls','ppeult','ppeulp','ppeulh','ppeum','ppeub','ppeubs','ppeus','ppeuss','ppeung','ppeuj','ppeuch','ppeuk','ppeut','ppeup','ppeuh','ppui','ppuig','ppuikk','ppuigs','ppuin','ppuinj','ppuinh','ppuid','ppuil','ppuilg','ppuilm','ppuilb','ppuils','ppuilt','ppuilp','ppuilh','ppuim','ppuib','ppuibs','ppuis','ppuiss','ppuing','ppuij','ppuich','ppuik','ppuit','ppuip','ppuih','ppi','ppig','ppikk','ppigs','ppin','ppinj','ppinh','ppid','ppil','ppilg','ppilm','ppilb','ppils','ppilt','ppilp','ppilh','ppim','ppib','ppibs','ppis','ppiss','pping','ppij','ppich','ppik','ppit','ppip','ppih','sa','sag','sakk','sags','san','sanj','sanh','sad','sal','salg','salm','salb','sals','salt','salp','salh','sam','sab','sabs','sas','sass','sang','saj','sach','sak','sat','sap','sah','sae','saeg','saekk','saegs','saen','saenj','saenh','saed','sael','saelg','saelm','saelb','saels','saelt','saelp','saelh','saem','saeb','saebs','saes','saess','saeng','saej','saech','saek','saet','saep','saeh','sya','syag','syakk','syags','syan','syanj','syanh','syad','syal','syalg','syalm','syalb','syals','syalt','syalp','syalh','syam','syab','syabs','syas','syass','syang','syaj','syach','syak','syat','syap','syah')


b=('jun','junj','junh','jud','jul','julg','julm','julb','juls','jult','julp','julh','jum','jub','jubs','jus','juss','jung','juj','juch','juk','jut','jup','juh','jwo','jwog','jwokk','jwogs','jwon','jwonj','jwonh','jwod','jwol','jwolg','jwolm','jwolb','jwols','jwolt','jwolp','jwolh','jwom','jwob','jwobs','jwos','jwoss','jwong','jwoj','jwoch','jwok','jwot','jwop','jwoh','jwe','jweg','jwekk','jwegs','jwen','jwenj','jwenh','jwed','jwel','jwelg','jwelm','jwelb','jwels','jwelt','jwelp','jwelh','jwem','jweb','jwebs','jwes','jwess','jweng','jwej','jwech','jwek','jwet','jwep','jweh','jwi','jwig','jwikk','jwigs','jwin','jwinj','jwinh','jwid','jwil','jwilg','jwilm','jwilb','jwils','jwilt','jwilp','jwilh','jwim','jwib','jwibs','jwis','jwiss','jwing','jwij','jwich','jwik','jwit','jwip','jwih','jyu','jyug','jyukk','jyugs','jyun','jyunj','jyunh','jyud','jyul','jyulg','jyulm','jyulb','jyuls','jyult','jyulp','jyulh','jyum','jyub','jyubs','jyus','jyuss','jyung','jyuj','jyuch','jyuk','jyut','jyup','jyuh','jeu','jeug','jeukk','jeugs','jeun','jeunj','jeunh','jeud','jeul','jeulg','jeulm','jeulb','jeuls','jeult','jeulp','jeulh','jeum','jeub','jeubs','jeus','jeuss','jeung','jeuj','jeuch','jeuk','jeut','jeup','jeuh','jui','juig','juikk','juigs','juin','juinj','juinh','juid','juil','juilg','juilm','juilb','juils','juilt','juilp','juilh','juim','juib','juibs','juis','juiss','juing','juij','juich','juik','juit','juip','juih','ji','jig','jikk','jigs','jin','jinj','jinh','jid','jil','jilg','jilm','jilb','jils','jilt','jilp','jilh','jim','jib','jibs','jis','jiss','jing','jij','jich','jik','jit','jip','jih','jja','jjag','jjakk','jjags','jjan','jjanj','jjanh','jjad','jjal','jjalg','jjalm','jjalb','jjals','jjalt','jjalp','jjalh','jjam','jjab','jjabs','jjas','jjass','jjang','jjaj','jjach','jjak','jjat','jjap','jjah','jjae','jjaeg','jjaekk','jjaegs','jjaen','jjaenj','jjaenh','jjaed')


b=('jjwaels','jjwaelt','jjwaelp','jjwaelh','jjwaem','jjwaeb','jjwaebs','jjwaes','jjwaess','jjwaeng','jjwaej','jjwaech','jjwaek','jjwaet','jjwaep','jjwaeh','jjoe','jjoeg','jjoekk','jjoegs','jjoen','jjoenj','jjoenh','jjoed','jjoel','jjoelg','jjoelm','jjoelb','jjoels','jjoelt','jjoelp','jjoelh','jjoem','jjoeb','jjoebs','jjoes','jjoess','jjoeng','jjoej','jjoech','jjoek','jjoet','jjoep','jjoeh','jjyo','jjyog','jjyokk','jjyogs','jjyon','jjyonj','jjyonh','jjyod','jjyol','jjyolg','jjyolm','jjyolb','jjyols','jjyolt','jjyolp','jjyolh','jjyom','jjyob','jjyobs','jjyos','jjyoss','jjyong','jjyoj','jjyoch','jjyok','jjyot','jjyop','jjyoh','jju','jjug','jjukk','jjugs','jjun','jjunj','jjunh','jjud','jjul','jjulg','jjulm','jjulb','jjuls','jjult','jjulp','jjulh','jjum','jjub','jjubs','jjus','jjuss','jjung','jjuj','jjuch','jjuk','jjut','jjup','jjuh','jjwo','jjwog','jjwokk','jjwogs','jjwon','jjwonj','jjwonh','jjwod','jjwol','jjwolg','jjwolm','jjwolb','jjwols','jjwolt','jjwolp','jjwolh','jjwom','jjwob','jjwobs','jjwos','jjwoss','jjwong','jjwoj','jjwoch','jjwok','jjwot','jjwop','jjwoh','jjwe','jjweg','jjwekk','jjwegs','jjwen','jjwenj','jjwenh','jjwed','jjwel','jjwelg','jjwelm','jjwelb','jjwels','jjwelt','jjwelp','jjwelh','jjwem','jjweb','jjwebs','jjwes','jjwess','jjweng','jjwej','jjwech','jjwek','jjwet','jjwep','jjweh','jjwi','jjwig','jjwikk','jjwigs','jjwin','jjwinj','jjwinh','jjwid','jjwil','jjwilg','jjwilm','jjwilb','jjwils','jjwilt','jjwilp','jjwilh','jjwim','jjwib','jjwibs','jjwis','jjwiss','jjwing','jjwij','jjwich','jjwik','jjwit','jjwip','jjwih','jjyu','jjyug','jjyukk','jjyugs','jjyun','jjyunj','jjyunh','jjyud','jjyul','jjyulg','jjyulm','jjyulb','jjyuls','jjyult','jjyulp','jjyulh','jjyum','jjyub','jjyubs','jjyus','jjyuss','jjyung','jjyuj','jjyuch','jjyuk','jjyut','jjyup','jjyuh','jjeu','jjeug','jjeukk','jjeugs','jjeun','jjeunj','jjeunh','jjeud','jjeul','jjeulg','jjeulm','jjeulb','jjeuls','jjeult','jjeulp','jjeulh','jjeum','jjeub','jjeubs','jjeus','jjeuss','jjeung','jjeuj','jjeuch','jjeuk','jjeut','jjeup','jjeuh','jjui','jjuig','jjuikk','jjuigs','jjuin','jjuinj','jjuinh','jjuid','jjuil','jjuilg','jjuilm','jjuilb','jjuils','jjuilt','jjuilp','jjuilh')


b=('gwan','gwanj','gwanh','gwad','gwal','gwalg','gwalm','gwalb','gwals','gwalt','gwalp','gwalh','gwam','gwab','gwabs','gwas','gwass','gwang','gwaj','gwach','gwak','gwat','gwap','gwah','gwae','gwaeg','gwaekk','gwaegs','gwaen','gwaenj','gwaenh','gwaed','gwael','gwaelg','gwaelm','gwaelb','gwaels','gwaelt','gwaelp','gwaelh','gwaem','gwaeb','gwaebs','gwaes','gwaess','gwaeng','gwaej','gwaech','gwaek','gwaet','gwaep','gwaeh','goe','goeg','goekk','goegs','goen','goenj','goenh','goed','goel','goelg','goelm','goelb','goels','goelt','goelp','goelh','goem','goeb','goebs','goes','goess','goeng','goej','goech','goek','goet','goep','goeh','gyo','gyog','gyokk','gyogs','gyon','gyonj','gyonh','gyod','gyol','gyolg','gyolm','gyolb','gyols','gyolt','gyolp','gyolh','gyom','gyob','gyobs','gyos','gyoss','gyong','gyoj','gyoch','gyok','gyot','gyop','gyoh','gu','gug','gukk','gugs','gun','gunj','gunh','gud','gul','gulg','gulm','gulb','guls','gult','gulp','gulh','gum','gub','gubs','gus','guss','gung','guj','guch','guk','gut','gup','guh','gwo','gwog','gwokk','gwogs','gwon','gwonj','gwonh','gwod','gwol','gwolg','gwolm','gwolb','gwols','gwolt','gwolp','gwolh','gwom','gwob','gwobs','gwos','gwoss','gwong','gwoj','gwoch','gwok','gwot','gwop','gwoh','gwe','gweg','gwekk','gwegs','gwen','gwenj','gwenh','gwed','gwel','gwelg','gwelm','gwelb','gwels','gwelt','gwelp','gwelh','gwem','gweb','gwebs','gwes','gwess','gweng','gwej','gwech','gwek','gwet','gwep','gweh','gwi','gwig','gwikk','gwigs','gwin','gwinj','gwinh','gwid','gwil','gwilg','gwilm','gwilb','gwils','gwilt','gwilp','gwilh','gwim','gwib','gwibs','gwis','gwiss','gwing','gwij','gwich','gwik','gwit','gwip','gwih','gyu','gyug','gyukk','gyugs','gyun','gyunj','gyunh','gyud','gyul','gyulg','gyulm','gyulb','gyuls','gyult','gyulp','gyulh','gyum','gyub','gyubs','gyus','gyuss','gyung','gyuj','gyuch','gyuk','gyut','gyup','gyuh','geu','geug','geukk','geugs','geun','geunj','geunh','geud')


b=('Xiao','Suo','Li','Zeng','Chu','Guo','Gao','E','Xiu','Cuo','Lue','Feng','Xin','Liu','Kai','Jian','Rui','Ti','Lang','Qin','Ju','A','Qiang','Zhe','Nuo','Cuo','Mao','Ben','Qi','De','Ke','Kun','Chang','Xi','Gu','Luo','Chui','Zhui','Jin','Zhi','Xian','Juan','Huo','Pei','Tan','Ding','Jian','Ju','Meng','Zi','Qie','Ying','Kai','Qiang','Si','E','Cha','Qiao','Zhong','Duan','Sou','Huang','Huan','Ai','Du','Mei','Lou','Zi','Fei','Mei','Mo','Zhen','Bo','Ge','Nie','Tang','Juan','Nie','Na','Liu','Gao','Bang','Yi','Jia','Bin','Rong','Biao','Tang','Man','Luo','Beng','Yong','Jing','Di','Zu','Xuan','Liu','Chan','Jue','Liao','Pu','Lu','Dui','Lan','Pu','Cuan','Qiang','Deng','Huo','Lei','Huan','Zhuo','Lian','Yi','Cha','Biao','La','Chan','Xiang','Zhang','Chang','Jiu','Ao','Die','Qu','Liao','Mi','Zhang','Men','Ma','Shuan','Shan','Huo','Men','Yan','Bi','Han','Bi','Shan','Kai','Kang','Beng','Hong','Run','San','Xian','Xian','Jian','Min','Xia','Shui','Dou','Zha','Nao','Zhan','Peng','Xia','Ling','Bian','Bi','Run','Ai','Guan','Ge','Ge','Fa','Chu','Hong','Gui','Min','Se','Kun','Lang','Lu','Ting','Sha','Ju','Yue','Yue','Chan','Qu','Lin','Chang','Shai','Kun','Yan','Wen','Yan','E','Hun','Yu','Wen','Hong','Bao','Hong','Qu','Yao','Wen','Ban','An','Wei','Yin','Kuo','Que','Lan','Du','Quan','Feng','Tian','Nie','Ta','Kai','He','Que','Chuang','Guan','Dou','Qi','Kui','Tang','Guan','Piao','Kan','Xi','Hui','Chan','Pi','Dang','Huan','Ta','Wen','Ta','Men','Shuan','Shan','Yan','Han','Bi','Wen','Chuang','Run','Wei','Xian','Hong','Jian','Min','Kang','Men','Zha','Nao','Gui','Wen','Ta','Min','Lu','Kai')


b=('Xu','Ji','Mu','Chen','Xiao','Zha','Ting','Zhen','Pei','Mei','Ling','Qi','Zhou','Huo','Sha','Fei','Hong','Zhan','Yin','Ni','Zhu','Tun','Lin','Ling','Dong','Ying','Wu','Ling','Shuang','Ling','Xia','Hong','Yin','Mai','Mai','Yun','Liu','Meng','Bin','Wu','Wei','Kuo','Yin','Xi','Yi','Ai','Dan','Teng','San','Yu','Lu','Long','Dai','Ji','Pang','Yang','Ba','Pi','Wei','Feng','Xi','Ji','Mai','Meng','Meng','Lei','Li','Huo','Ai','Fei','Dai','Long','Ling','Ai','Feng','Li','Bao','He','He','He','Bing','Qing','Qing','Jing','Tian','Zhen','Jing','Cheng','Qing','Jing','Jing','Dian','Jing','Tian','Fei','Fei','Kao','Mi','Mian','Mian','Bao','Ye','Tian','Hui','Ye','Ge','Ding','Cha','Qian','Ren','Di','Du','Wu','Ren','Qin','Jin','Xue','Niu','Ba','Yin','Sa','Na','Mo','Zu','Da','Ban','Yi','Yao','Tao','Bei','Jie','Hong','Pao','Yang','Bing','Yin','Ge','Tao','Jie','Xie','An','An','Hen','Gong','Qia','Da','Qiao','Ting','Man','Ying','Sui','Tiao','Qiao','Xuan','Kong','Beng','Ta','Shang','Bing','Kuo','Ju','La','Xie','Rou','Bang','Eng','Qiu','Qiu','He','Qiao','Mu','Ju','Jian','Bian','Di','Jian','Wen','Tao','Gou','Ta','Bei','Xie','Pan','Ge','Bi','Kuo','Tang','Lou','Gui','Qiao','Xue','Ji','Jian','Jiang','Chan','Da','Hu','Xian','Qian','Du','Wa','Jian','Lan','Wei','Ren','Fu','Mei','Quan','Ge','Wei','Qiao','Han','Chang','Kuo','Rou','Yun','She','Wei','Ge','Bai','Tao','Gou','Yun','Gao','Bi','Wei','Sui','Du','Wa','Du','Wei','Ren','Fu','Han','Wei','Yun','Tao','Jiu','Jiu','Xian','Xie','Xian','Ji','Yin','Za','Yun','Shao','Le','Peng','Huang','Ying','Yun','Peng','An','Yin','Xiang')


b=('chwik','chwit','chwip','chwih','chyu','chyug','chyukk','chyugs','chyun','chyunj','chyunh','chyud','chyul','chyulg','chyulm','chyulb','chyuls','chyult','chyulp','chyulh','chyum','chyub','chyubs','chyus','chyuss','chyung','chyuj','chyuch','chyuk','chyut','chyup','chyuh','cheu','cheug','cheukk','cheugs','cheun','cheunj','cheunh','cheud','cheul','cheulg','cheulm','cheulb','cheuls','cheult','cheulp','cheulh','cheum','cheub','cheubs','cheus','cheuss','cheung','cheuj','cheuch','cheuk','cheut','cheup','cheuh','chui','chuig','chuikk','chuigs','chuin','chuinj','chuinh','chuid','chuil','chuilg','chuilm','chuilb','chuils','chuilt','chuilp','chuilh','chuim','chuib','chuibs','chuis','chuiss','chuing','chuij','chuich','chuik','chuit','chuip','chuih','chi','chig','chikk','chigs','chin','chinj','chinh','chid','chil','chilg','chilm','chilb','chils','chilt','chilp','chilh','chim','chib','chibs','chis','chiss','ching','chij','chich','chik','chit','chip','chih','ka','kag','kakk','kags','kan','kanj','kanh','kad','kal','kalg','kalm','kalb','kals','kalt','kalp','kalh','kam','kab','kabs','kas','kass','kang','kaj','kach','kak','kat','kap','kah','kae','kaeg','kaekk','kaegs','kaen','kaenj','kaenh','kaed','kael','kaelg','kaelm','kaelb','kaels','kaelt','kaelp','kaelh','kaem','kaeb','kaebs','kaes','kaess','kaeng','kaej','kaech','kaek','kaet','kaep','kaeh','kya','kyag','kyakk','kyags','kyan','kyanj','kyanh','kyad','kyal','kyalg','kyalm','kyalb','kyals','kyalt','kyalp','kyalh','kyam','kyab','kyabs','kyas','kyass','kyang','kyaj','kyach','kyak','kyat','kyap','kyah','kyae','kyaeg','kyaekk','kyaegs','kyaen','kyaenj','kyaenh','kyaed','kyael','kyaelg','kyaelm','kyaelb','kyaels','kyaelt','kyaelp','kyaelh','kyaem','kyaeb','kyaebs','kyaes','kyaess','kyaeng','kyaej','kyaech','kyaek','kyaet','kyaep','kyaeh','keo','keog','keokk','keogs','keon','keonj','keonh','keod','keol','keolg','keolm','keolb','keols','keolt','keolp','keolh','keom','keob','keobs','keos','keoss','keong','keoj','keoch','keok','keot','keop','keoh')


b=('ke','keg','kekk','kegs','ken','kenj','kenh','ked','kel','kelg','kelm','kelb','kels','kelt','kelp','kelh','kem','keb','kebs','kes','kess','keng','kej','kech','kek','ket','kep','keh','kyeo','kyeog','kyeokk','kyeogs','kyeon','kyeonj','kyeonh','kyeod','kyeol','kyeolg','kyeolm','kyeolb','kyeols','kyeolt','kyeolp','kyeolh','kyeom','kyeob','kyeobs','kyeos','kyeoss','kyeong','kyeoj','kyeoch','kyeok','kyeot','kyeop','kyeoh','kye','kyeg','kyekk','kyegs','kyen','kyenj','kyenh','kyed','kyel','kyelg','kyelm','kyelb','kyels','kyelt','kyelp','kyelh','kyem','kyeb','kyebs','kyes','kyess','kyeng','kyej','kyech','kyek','kyet','kyep','kyeh','ko','kog','kokk','kogs','kon','konj','konh','kod','kol','kolg','kolm','kolb','kols','kolt','kolp','kolh','kom','kob','kobs','kos','koss','kong','koj','koch','kok','kot','kop','koh','kwa','kwag','kwakk','kwags','kwan','kwanj','kwanh','kwad','kwal','kwalg','kwalm','kwalb','kwals','kwalt','kwalp','kwalh','kwam','kwab','kwabs','kwas','kwass','kwang','kwaj','kwach','kwak','kwat','kwap','kwah','kwae','kwaeg','kwaekk','kwaegs','kwaen','kwaenj','kwaenh','kwaed','kwael','kwaelg','kwaelm','kwaelb','kwaels','kwaelt','kwaelp','kwaelh','kwaem','kwaeb','kwaebs','kwaes','kwaess','kwaeng','kwaej','kwaech','kwaek','kwaet','kwaep','kwaeh','koe','koeg','koekk','koegs','koen','koenj','koenh','koed','koel','koelg','koelm','koelb','koels','koelt','koelp','koelh','koem','koeb','koebs','koes','koess','koeng','koej','koech','koek','koet','koep','koeh','kyo','kyog','kyokk','kyogs','kyon','kyonj','kyonh','kyod','kyol','kyolg','kyolm','kyolb','kyols','kyolt','kyolp','kyolh','kyom','kyob','kyobs','kyos','kyoss','kyong','kyoj','kyoch','kyok','kyot','kyop','kyoh','ku','kug','kukk','kugs','kun','kunj','kunh','kud','kul','kulg','kulm','kulb','kuls','kult','kulp','kulh','kum','kub','kubs','kus','kuss','kung','kuj','kuch','kuk','kut','kup','kuh','kwo','kwog','kwokk','kwogs')


import os
import setuptools


def read(fname):
    p = os.path.join(os.path.dirname(__file__), fname)
    if os.path.exists(p):
        return open(p, encoding='utf-8').read()
    else:
        return ""


setuptools.setup(
    author="Hunter WB",
    author_email="hunter@hunterwb.com",
    name='anyascii',
    version='0.1.3',
    description='Unicode to ASCII transliteration',
    long_description=read('../README.md'),
    long_description_content_type='text/markdown',
    license='ISC',
    url='https://github.com/hunterwb/any-ascii',
    packages=setuptools.find_packages(),
    python_requires=">=3.3",
    zip_safe=True,
    classifiers=[
        'License :: OSI Approved :: ISC License (ISCL)',
        'Topic :: Text Processing :: Linguistic',
        'Topic :: Text Processing',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
    ]
)


b=('Bu','Zhang','Lei','Qiang','Man','Yan','Ling','Ji','Biao','Gun','Han','Di','Su','Lu','She','Shang','Di','Mie','Xun','Man','Bo','Di','Cuo','Zhe','Shen','Xuan','Wei','Hu','Ao','Mi','Lou','Cu','Zhong','Cai','Po','Jiang','Mi','Cong','Niao','Hui','Juan','Yin','Jian','Nian','Shu','Yin','Guo','Chen','Hu','Sha','Kou','Qian','Ma','Zang','Ze','Qiang','Dou','Lian','Lin','Kou','Ai','Bi','Li','Wei','Ji','Qian','Sheng','Fan','Meng','Ou','Chan','Dian','Xun','Jiao','Rui','Rui','Lei','Yu','Qiao','Chu','Hua','Jian','Mai','Yun','Bao','You','Qu','Lu','Rao','Hui','E','Ti','Fei','Jue','Zui','Fa','Ru','Fen','Kui','Shun','Rui','Ya','Xu','Fu','Jue','Dang','Wu','Dong','Si','Xiao','Xi','Long','Wen','Shao','Qi','Jian','Yun','Sun','Ling','Yu','Xia','Weng','Ji','Hong','Si','Nong','Lei','Xuan','Yun','Yu','Xi','Hao','Bao','Hao','Ai','Wei','Hui','Hui','Ji','Ci','Xiang','Wan','Mie','Yi','Leng','Jiang','Can','Shen','Qiang','Lian','Ke','Yuan','Da','Ti','Tang','Xue','Bi','Zhan','Sun','Xian','Fan','Ding','Xie','Gu','Xie','Shu','Jian','Hao','Hong','Sa','Xin','Xun','Yao','Bai','Sou','Shu','Xun','Dui','Pin','Wei','Ning','Chou','Mai','Ru','Piao','Tai','Ji','Zao','Chen','Zhen','Er','Ni','Ying','Gao','Cong','Xiao','Qi','Fa','Jian','Xu','Kui','Ji','Bian','Diao','Mi','Lan','Jin','Cang','Miao','Qiong','Qie','Xian','Liao','Ou','Xian','Su','Lu','Yi','Xu','Xie','Li','Yi','La','Lei','Jiao','Di','Zhi','Bei','Teng','Yao','Mo','Huan','Biao','Fan','Sou','Tan','Tui','Qiong','Qiao','Wei','Liu','Hui','Ou','Gao','Yun','Bao','Li','Shu','Chu','Ai','Lin','Zao','Xuan','Qin','Lai','Huo')


b=('pyuk','pyut','pyup','pyuh','peu','peug','peukk','peugs','peun','peunj','peunh','peud','peul','peulg','peulm','peulb','peuls','peult','peulp','peulh','peum','peub','peubs','peus','peuss','peung','peuj','peuch','peuk','peut','peup','peuh','pui','puig','puikk','puigs','puin','puinj','puinh','puid','puil','puilg','puilm','puilb','puils','puilt','puilp','puilh','puim','puib','puibs','puis','puiss','puing','puij','puich','puik','puit','puip','puih','pi','pig','pikk','pigs','pin','pinj','pinh','pid','pil','pilg','pilm','pilb','pils','pilt','pilp','pilh','pim','pib','pibs','pis','piss','ping','pij','pich','pik','pit','pip','pih','ha','hag','hakk','hags','han','hanj','hanh','had','hal','halg','halm','halb','hals','halt','halp','halh','ham','hab','habs','has','hass','hang','haj','hach','hak','hat','hap','hah','hae','haeg','haekk','haegs','haen','haenj','haenh','haed','hael','haelg','haelm','haelb','haels','haelt','haelp','haelh','haem','haeb','haebs','haes','haess','haeng','haej','haech','haek','haet','haep','haeh','hya','hyag','hyakk','hyags','hyan','hyanj','hyanh','hyad','hyal','hyalg','hyalm','hyalb','hyals','hyalt','hyalp','hyalh','hyam','hyab','hyabs','hyas','hyass','hyang','hyaj','hyach','hyak','hyat','hyap','hyah','hyae','hyaeg','hyaekk','hyaegs','hyaen','hyaenj','hyaenh','hyaed','hyael','hyaelg','hyaelm','hyaelb','hyaels','hyaelt','hyaelp','hyaelh','hyaem','hyaeb','hyaebs','hyaes','hyaess','hyaeng','hyaej','hyaech','hyaek','hyaet','hyaep','hyaeh','heo','heog','heokk','heogs','heon','heonj','heonh','heod','heol','heolg','heolm','heolb','heols','heolt','heolp','heolh','heom','heob','heobs','heos','heoss','heong','heoj','heoch','heok','heot','heop','heoh','he','heg','hekk','hegs','hen','henj','henh','hed','hel','helg','helm','helb','hels','helt','help','helh','hem','heb','hebs','hes','hess','heng','hej','hech','hek','het','hep','heh')


b=('dae','daeg','daekk','daegs','daen','daenj','daenh','daed','dael','daelg','daelm','daelb','daels','daelt','daelp','daelh','daem','daeb','daebs','daes','daess','daeng','daej','daech','daek','daet','daep','daeh','dya','dyag','dyakk','dyags','dyan','dyanj','dyanh','dyad','dyal','dyalg','dyalm','dyalb','dyals','dyalt','dyalp','dyalh','dyam','dyab','dyabs','dyas','dyass','dyang','dyaj','dyach','dyak','dyat','dyap','dyah','dyae','dyaeg','dyaekk','dyaegs','dyaen','dyaenj','dyaenh','dyaed','dyael','dyaelg','dyaelm','dyaelb','dyaels','dyaelt','dyaelp','dyaelh','dyaem','dyaeb','dyaebs','dyaes','dyaess','dyaeng','dyaej','dyaech','dyaek','dyaet','dyaep','dyaeh','deo','deog','deokk','deogs','deon','deonj','deonh','deod','deol','deolg','deolm','deolb','deols','deolt','deolp','deolh','deom','deob','deobs','deos','deoss','deong','deoj','deoch','deok','deot','deop','deoh','de','deg','dekk','degs','den','denj','denh','ded','del','delg','delm','delb','dels','delt','delp','delh','dem','deb','debs','des','dess','deng','dej','dech','dek','det','dep','deh','dyeo','dyeog','dyeokk','dyeogs','dyeon','dyeonj','dyeonh','dyeod','dyeol','dyeolg','dyeolm','dyeolb','dyeols','dyeolt','dyeolp','dyeolh','dyeom','dyeob','dyeobs','dyeos','dyeoss','dyeong','dyeoj','dyeoch','dyeok','dyeot','dyeop','dyeoh','dye','dyeg','dyekk','dyegs','dyen','dyenj','dyenh','dyed','dyel','dyelg','dyelm','dyelb','dyels','dyelt','dyelp','dyelh','dyem','dyeb','dyebs','dyes','dyess','dyeng','dyej','dyech','dyek','dyet','dyep','dyeh','do','dog','dokk','dogs','don','donj','donh','dod','dol','dolg','dolm','dolb','dols','dolt','dolp','dolh','dom','dob','dobs','dos','doss','dong','doj','doch','dok','dot','dop','doh','dwa','dwag','dwakk','dwags','dwan','dwanj','dwanh','dwad','dwal','dwalg','dwalm','dwalb','dwals','dwalt','dwalp','dwalh','dwam','dwab','dwabs','dwas','dwass','dwang','dwaj','dwach','dwak','dwat','dwap','dwah','dwae','dwaeg','dwaekk','dwaegs')


b=('Pan','Yang','Lei','Ca','Shu','Zan','Nian','Xian','Jun','Huo','Li','La','Huan','Ying','Lu','Long','Qian','Qian','Zan','Qian','Lan','Xian','Ying','Mei','Rang','Chan','Weng','Cuan','Xie','She','Luo','Jun','Mi','Chi','Zan','Luan','Tan','Zuan','Li','Dian','Wa','Dang','Jiao','Jue','Lan','Li','Nang','Zhi','Gui','Gui','Qi','Xun','Pu','Pu','Shou','Kao','You','Gai','Yi','Gong','Gan','Ban','Fang','Zheng','Po','Dian','Kou','Min','Wu','Gu','He','Ce','Xiao','Mi','Chu','Ge','Di','Xu','Jiao','Min','Chen','Jiu','Shen','Duo','Yu','Chi','Ao','Bai','Xu','Jiao','Duo','Lian','Nie','Bi','Chang','Dian','Duo','Yi','Gan','San','Ke','Yan','Dun','Ji','Tou','Xiao','Duo','Jiao','Jing','Yang','Xia','Min','Shu','Ai','Qiao','Ai','Zheng','Di','Zhen','Fu','Shu','Liao','Qu','Xiong','Yi','Jiao','Shan','Jiao','Zhuo','Yi','Lian','Bi','Li','Xiao','Xiao','Wen','Xue','Qi','Qi','Zhai','Bin','Jue','Zhai','Lang','Fei','Ban','Ban','Lan','Yu','Lan','Wei','Dou','Sheng','Liao','Jia','Hu','Xie','Jia','Yu','Zhen','Jiao','Wo','Tiao','Dou','Jin','Chi','Yin','Fu','Qiang','Zhan','Qu','Zhuo','Zhan','Duan','Cuo','Si','Xin','Zhuo','Zhuo','Qin','Lin','Zhuo','Chu','Duan','Zhu','Fang','Chan','Hang','Yu','Shi','Pei','You','Mei','Pang','Qi','Zhan','Mao','Lu','Pei','Pi','Liu','Fu','Fang','Xuan','Jing','Jing','Ni','Zu','Zhao','Yi','Liu','Shao','Jian','Yu','Yi','Qi','Zhi','Fan','Piao','Fan','Zhan','Kuai','Sui','Yu','Wu','Ji','Ji','Ji','Huo','Ri','Dan','Jiu','Zhi','Zao','Xie','Tiao','Xun','Xu','Ga','La','Gan','Han','Tai','Di','Xu','Chan','Shi','Kuang','Yang','Shi','Wang','Min','Min','Tun','Chun','Wu')